from make87_messages_ros2.jazzy.builtin_interfaces.msg import duration_pb2 as _duration_pb2
from make87_messages_ros2.jazzy.rmf_obstacle_msgs.msg import bounding_box3_d_pb2 as _bounding_box3_d_pb2
from make87_messages_ros2.jazzy.std_msgs.msg import header_pb2 as _header_pb2
from google.protobuf.internal import containers as _containers
from google.protobuf import descriptor as _descriptor
from google.protobuf import message as _message
from typing import ClassVar as _ClassVar, Iterable as _Iterable, Mapping as _Mapping, Optional as _Optional, Union as _Union

DESCRIPTOR: _descriptor.FileDescriptor

class Obstacle(_message.Message):
    __slots__ = ["header", "id", "source", "level_name", "classification", "bbox", "data_resolution", "data", "lifetime", "action"]
    HEADER_FIELD_NUMBER: _ClassVar[int]
    ID_FIELD_NUMBER: _ClassVar[int]
    SOURCE_FIELD_NUMBER: _ClassVar[int]
    LEVEL_NAME_FIELD_NUMBER: _ClassVar[int]
    CLASSIFICATION_FIELD_NUMBER: _ClassVar[int]
    BBOX_FIELD_NUMBER: _ClassVar[int]
    DATA_RESOLUTION_FIELD_NUMBER: _ClassVar[int]
    DATA_FIELD_NUMBER: _ClassVar[int]
    LIFETIME_FIELD_NUMBER: _ClassVar[int]
    ACTION_FIELD_NUMBER: _ClassVar[int]
    header: _header_pb2.Header
    id: int
    source: str
    level_name: str
    classification: str
    bbox: _bounding_box3_d_pb2.BoundingBox3D
    data_resolution: float
    data: _containers.RepeatedScalarFieldContainer[int]
    lifetime: _duration_pb2.Duration
    action: int
    def __init__(self, header: _Optional[_Union[_header_pb2.Header, _Mapping]] = ..., id: _Optional[int] = ..., source: _Optional[str] = ..., level_name: _Optional[str] = ..., classification: _Optional[str] = ..., bbox: _Optional[_Union[_bounding_box3_d_pb2.BoundingBox3D, _Mapping]] = ..., data_resolution: _Optional[float] = ..., data: _Optional[_Iterable[int]] = ..., lifetime: _Optional[_Union[_duration_pb2.Duration, _Mapping]] = ..., action: _Optional[int] = ...) -> None: ...



from make87_messages_ros2.jazzy.std_msgs.msg import header_pb2 as _header_pb2
from google.protobuf import descriptor as _descriptor
from google.protobuf import message as _message
from typing import ClassVar as _ClassVar, Mapping as _Mapping, Optional as _Optional, Union as _Union

DESCRIPTOR: _descriptor.FileDescriptor

class ActiveFaultLatched1(_message.Message):
    __slots__ = ["header", "active_flt_latched_byte7_bit7", "active_flt_latched_byte7_bit6", "active_flt_latched_byte7_bit5", "active_flt_latched_byte7_bit4", "arm_to_dsp_chksum_fault", "dsp_to_arm_chksum_fault", "host_to_arm_chksum_fault", "arm_to_host_chksum_fault", "loop_bw_out_of_range", "dsp_overrun_fault", "active_flt_latched_byte6_bit5", "tuning_sensitivity_fault", "saturated_tuning_freq_fault", "local_osc_power_fault", "transmitter_power_fault", "active_flt_latched_byte6_bit0", "active_flt_latched_byte5_bit7", "active_flt_latched_byte5_bit6", "xcvr_device_spi_fault", "freq_synthesizer_spi_fault", "analog_converter_devic_spi_fault", "side_lobe_blockage", "active_flt_latched_byte5_bit1", "mnr_blocked", "ecu_temp_high_fault", "transmitter_temp_high_fault", "alignment_routine_failed_fault", "unreasonable_radar_data", "microprocessor_temp_high_fault", "vertical_alignment_out_of_range", "horizontal_alignment_out_of_range", "factory_alignment_mode", "battery_low_fault", "battery_high_fault", "v_1p25_supply_out_of_range", "active_flt_latched_byte3_bit4", "thermistor_out_of_range", "v_3p3_dac_supply_out_of_range", "v_3p3_raw_supply_out_of_range", "v_5_supply_out_of_range", "transmitter_id_fault", "active_flt_latched_byte2_bit6", "active_flt_latched_byte2_bit5", "active_flt_latched_byte2_bit4", "active_flt_latched_byte2_bit3", "active_flt_latched_byte2_bit2", "pcan_missing_msg_fault", "pcan_bus_off", "active_flt_latched_byte1_bit7", "active_flt_latched_byte1_bit6", "instruction_set_check_fault", "stack_overflow_fault", "watchdog_fault", "pll_lock_fault", "active_flt_latched_byte1_bit1", "ram_memory_test_fault", "usc_validation_fault", "active_flt_latched_byte0_bit6", "active_flt_latched_byte0_bit5", "active_flt_latched_byte0_bit4", "active_flt_latched_byte0_bit3", "keep_alive_checksum_fault", "program_calibration_flash_checksum", "application_flash_checksum_fault"]
    HEADER_FIELD_NUMBER: _ClassVar[int]
    ACTIVE_FLT_LATCHED_BYTE7_BIT7_FIELD_NUMBER: _ClassVar[int]
    ACTIVE_FLT_LATCHED_BYTE7_BIT6_FIELD_NUMBER: _ClassVar[int]
    ACTIVE_FLT_LATCHED_BYTE7_BIT5_FIELD_NUMBER: _ClassVar[int]
    ACTIVE_FLT_LATCHED_BYTE7_BIT4_FIELD_NUMBER: _ClassVar[int]
    ARM_TO_DSP_CHKSUM_FAULT_FIELD_NUMBER: _ClassVar[int]
    DSP_TO_ARM_CHKSUM_FAULT_FIELD_NUMBER: _ClassVar[int]
    HOST_TO_ARM_CHKSUM_FAULT_FIELD_NUMBER: _ClassVar[int]
    ARM_TO_HOST_CHKSUM_FAULT_FIELD_NUMBER: _ClassVar[int]
    LOOP_BW_OUT_OF_RANGE_FIELD_NUMBER: _ClassVar[int]
    DSP_OVERRUN_FAULT_FIELD_NUMBER: _ClassVar[int]
    ACTIVE_FLT_LATCHED_BYTE6_BIT5_FIELD_NUMBER: _ClassVar[int]
    TUNING_SENSITIVITY_FAULT_FIELD_NUMBER: _ClassVar[int]
    SATURATED_TUNING_FREQ_FAULT_FIELD_NUMBER: _ClassVar[int]
    LOCAL_OSC_POWER_FAULT_FIELD_NUMBER: _ClassVar[int]
    TRANSMITTER_POWER_FAULT_FIELD_NUMBER: _ClassVar[int]
    ACTIVE_FLT_LATCHED_BYTE6_BIT0_FIELD_NUMBER: _ClassVar[int]
    ACTIVE_FLT_LATCHED_BYTE5_BIT7_FIELD_NUMBER: _ClassVar[int]
    ACTIVE_FLT_LATCHED_BYTE5_BIT6_FIELD_NUMBER: _ClassVar[int]
    XCVR_DEVICE_SPI_FAULT_FIELD_NUMBER: _ClassVar[int]
    FREQ_SYNTHESIZER_SPI_FAULT_FIELD_NUMBER: _ClassVar[int]
    ANALOG_CONVERTER_DEVIC_SPI_FAULT_FIELD_NUMBER: _ClassVar[int]
    SIDE_LOBE_BLOCKAGE_FIELD_NUMBER: _ClassVar[int]
    ACTIVE_FLT_LATCHED_BYTE5_BIT1_FIELD_NUMBER: _ClassVar[int]
    MNR_BLOCKED_FIELD_NUMBER: _ClassVar[int]
    ECU_TEMP_HIGH_FAULT_FIELD_NUMBER: _ClassVar[int]
    TRANSMITTER_TEMP_HIGH_FAULT_FIELD_NUMBER: _ClassVar[int]
    ALIGNMENT_ROUTINE_FAILED_FAULT_FIELD_NUMBER: _ClassVar[int]
    UNREASONABLE_RADAR_DATA_FIELD_NUMBER: _ClassVar[int]
    MICROPROCESSOR_TEMP_HIGH_FAULT_FIELD_NUMBER: _ClassVar[int]
    VERTICAL_ALIGNMENT_OUT_OF_RANGE_FIELD_NUMBER: _ClassVar[int]
    HORIZONTAL_ALIGNMENT_OUT_OF_RANGE_FIELD_NUMBER: _ClassVar[int]
    FACTORY_ALIGNMENT_MODE_FIELD_NUMBER: _ClassVar[int]
    BATTERY_LOW_FAULT_FIELD_NUMBER: _ClassVar[int]
    BATTERY_HIGH_FAULT_FIELD_NUMBER: _ClassVar[int]
    V_1P25_SUPPLY_OUT_OF_RANGE_FIELD_NUMBER: _ClassVar[int]
    ACTIVE_FLT_LATCHED_BYTE3_BIT4_FIELD_NUMBER: _ClassVar[int]
    THERMISTOR_OUT_OF_RANGE_FIELD_NUMBER: _ClassVar[int]
    V_3P3_DAC_SUPPLY_OUT_OF_RANGE_FIELD_NUMBER: _ClassVar[int]
    V_3P3_RAW_SUPPLY_OUT_OF_RANGE_FIELD_NUMBER: _ClassVar[int]
    V_5_SUPPLY_OUT_OF_RANGE_FIELD_NUMBER: _ClassVar[int]
    TRANSMITTER_ID_FAULT_FIELD_NUMBER: _ClassVar[int]
    ACTIVE_FLT_LATCHED_BYTE2_BIT6_FIELD_NUMBER: _ClassVar[int]
    ACTIVE_FLT_LATCHED_BYTE2_BIT5_FIELD_NUMBER: _ClassVar[int]
    ACTIVE_FLT_LATCHED_BYTE2_BIT4_FIELD_NUMBER: _ClassVar[int]
    ACTIVE_FLT_LATCHED_BYTE2_BIT3_FIELD_NUMBER: _ClassVar[int]
    ACTIVE_FLT_LATCHED_BYTE2_BIT2_FIELD_NUMBER: _ClassVar[int]
    PCAN_MISSING_MSG_FAULT_FIELD_NUMBER: _ClassVar[int]
    PCAN_BUS_OFF_FIELD_NUMBER: _ClassVar[int]
    ACTIVE_FLT_LATCHED_BYTE1_BIT7_FIELD_NUMBER: _ClassVar[int]
    ACTIVE_FLT_LATCHED_BYTE1_BIT6_FIELD_NUMBER: _ClassVar[int]
    INSTRUCTION_SET_CHECK_FAULT_FIELD_NUMBER: _ClassVar[int]
    STACK_OVERFLOW_FAULT_FIELD_NUMBER: _ClassVar[int]
    WATCHDOG_FAULT_FIELD_NUMBER: _ClassVar[int]
    PLL_LOCK_FAULT_FIELD_NUMBER: _ClassVar[int]
    ACTIVE_FLT_LATCHED_BYTE1_BIT1_FIELD_NUMBER: _ClassVar[int]
    RAM_MEMORY_TEST_FAULT_FIELD_NUMBER: _ClassVar[int]
    USC_VALIDATION_FAULT_FIELD_NUMBER: _ClassVar[int]
    ACTIVE_FLT_LATCHED_BYTE0_BIT6_FIELD_NUMBER: _ClassVar[int]
    ACTIVE_FLT_LATCHED_BYTE0_BIT5_FIELD_NUMBER: _ClassVar[int]
    ACTIVE_FLT_LATCHED_BYTE0_BIT4_FIELD_NUMBER: _ClassVar[int]
    ACTIVE_FLT_LATCHED_BYTE0_BIT3_FIELD_NUMBER: _ClassVar[int]
    KEEP_ALIVE_CHECKSUM_FAULT_FIELD_NUMBER: _ClassVar[int]
    PROGRAM_CALIBRATION_FLASH_CHECKSUM_FIELD_NUMBER: _ClassVar[int]
    APPLICATION_FLASH_CHECKSUM_FAULT_FIELD_NUMBER: _ClassVar[int]
    header: _header_pb2.Header
    active_flt_latched_byte7_bit7: bool
    active_flt_latched_byte7_bit6: bool
    active_flt_latched_byte7_bit5: bool
    active_flt_latched_byte7_bit4: bool
    arm_to_dsp_chksum_fault: bool
    dsp_to_arm_chksum_fault: bool
    host_to_arm_chksum_fault: bool
    arm_to_host_chksum_fault: bool
    loop_bw_out_of_range: bool
    dsp_overrun_fault: bool
    active_flt_latched_byte6_bit5: bool
    tuning_sensitivity_fault: bool
    saturated_tuning_freq_fault: bool
    local_osc_power_fault: bool
    transmitter_power_fault: bool
    active_flt_latched_byte6_bit0: bool
    active_flt_latched_byte5_bit7: bool
    active_flt_latched_byte5_bit6: bool
    xcvr_device_spi_fault: bool
    freq_synthesizer_spi_fault: bool
    analog_converter_devic_spi_fault: bool
    side_lobe_blockage: bool
    active_flt_latched_byte5_bit1: bool
    mnr_blocked: bool
    ecu_temp_high_fault: bool
    transmitter_temp_high_fault: bool
    alignment_routine_failed_fault: bool
    unreasonable_radar_data: bool
    microprocessor_temp_high_fault: bool
    vertical_alignment_out_of_range: bool
    horizontal_alignment_out_of_range: bool
    factory_alignment_mode: bool
    battery_low_fault: bool
    battery_high_fault: bool
    v_1p25_supply_out_of_range: bool
    active_flt_latched_byte3_bit4: bool
    thermistor_out_of_range: bool
    v_3p3_dac_supply_out_of_range: bool
    v_3p3_raw_supply_out_of_range: bool
    v_5_supply_out_of_range: bool
    transmitter_id_fault: bool
    active_flt_latched_byte2_bit6: bool
    active_flt_latched_byte2_bit5: bool
    active_flt_latched_byte2_bit4: bool
    active_flt_latched_byte2_bit3: bool
    active_flt_latched_byte2_bit2: bool
    pcan_missing_msg_fault: bool
    pcan_bus_off: bool
    active_flt_latched_byte1_bit7: bool
    active_flt_latched_byte1_bit6: bool
    instruction_set_check_fault: bool
    stack_overflow_fault: bool
    watchdog_fault: bool
    pll_lock_fault: bool
    active_flt_latched_byte1_bit1: bool
    ram_memory_test_fault: bool
    usc_validation_fault: bool
    active_flt_latched_byte0_bit6: bool
    active_flt_latched_byte0_bit5: bool
    active_flt_latched_byte0_bit4: bool
    active_flt_latched_byte0_bit3: bool
    keep_alive_checksum_fault: bool
    program_calibration_flash_checksum: bool
    application_flash_checksum_fault: bool
    def __init__(self, header: _Optional[_Union[_header_pb2.Header, _Mapping]] = ..., active_flt_latched_byte7_bit7: bool = ..., active_flt_latched_byte7_bit6: bool = ..., active_flt_latched_byte7_bit5: bool = ..., active_flt_latched_byte7_bit4: bool = ..., arm_to_dsp_chksum_fault: bool = ..., dsp_to_arm_chksum_fault: bool = ..., host_to_arm_chksum_fault: bool = ..., arm_to_host_chksum_fault: bool = ..., loop_bw_out_of_range: bool = ..., dsp_overrun_fault: bool = ..., active_flt_latched_byte6_bit5: bool = ..., tuning_sensitivity_fault: bool = ..., saturated_tuning_freq_fault: bool = ..., local_osc_power_fault: bool = ..., transmitter_power_fault: bool = ..., active_flt_latched_byte6_bit0: bool = ..., active_flt_latched_byte5_bit7: bool = ..., active_flt_latched_byte5_bit6: bool = ..., xcvr_device_spi_fault: bool = ..., freq_synthesizer_spi_fault: bool = ..., analog_converter_devic_spi_fault: bool = ..., side_lobe_blockage: bool = ..., active_flt_latched_byte5_bit1: bool = ..., mnr_blocked: bool = ..., ecu_temp_high_fault: bool = ..., transmitter_temp_high_fault: bool = ..., alignment_routine_failed_fault: bool = ..., unreasonable_radar_data: bool = ..., microprocessor_temp_high_fault: bool = ..., vertical_alignment_out_of_range: bool = ..., horizontal_alignment_out_of_range: bool = ..., factory_alignment_mode: bool = ..., battery_low_fault: bool = ..., battery_high_fault: bool = ..., v_1p25_supply_out_of_range: bool = ..., active_flt_latched_byte3_bit4: bool = ..., thermistor_out_of_range: bool = ..., v_3p3_dac_supply_out_of_range: bool = ..., v_3p3_raw_supply_out_of_range: bool = ..., v_5_supply_out_of_range: bool = ..., transmitter_id_fault: bool = ..., active_flt_latched_byte2_bit6: bool = ..., active_flt_latched_byte2_bit5: bool = ..., active_flt_latched_byte2_bit4: bool = ..., active_flt_latched_byte2_bit3: bool = ..., active_flt_latched_byte2_bit2: bool = ..., pcan_missing_msg_fault: bool = ..., pcan_bus_off: bool = ..., active_flt_latched_byte1_bit7: bool = ..., active_flt_latched_byte1_bit6: bool = ..., instruction_set_check_fault: bool = ..., stack_overflow_fault: bool = ..., watchdog_fault: bool = ..., pll_lock_fault: bool = ..., active_flt_latched_byte1_bit1: bool = ..., ram_memory_test_fault: bool = ..., usc_validation_fault: bool = ..., active_flt_latched_byte0_bit6: bool = ..., active_flt_latched_byte0_bit5: bool = ..., active_flt_latched_byte0_bit4: bool = ..., active_flt_latched_byte0_bit3: bool = ..., keep_alive_checksum_fault: bool = ..., program_calibration_flash_checksum: bool = ..., application_flash_checksum_fault: bool = ...) -> None: ...



from google.protobuf import descriptor as _descriptor
from google.protobuf import message as _message
from typing import ClassVar as _ClassVar, Optional as _Optional

DESCRIPTOR: _descriptor.FileDescriptor

class TypeSource(_message.Message):
    __slots__ = ["type_name", "encoding", "raw_file_contents"]
    TYPE_NAME_FIELD_NUMBER: _ClassVar[int]
    ENCODING_FIELD_NUMBER: _ClassVar[int]
    RAW_FILE_CONTENTS_FIELD_NUMBER: _ClassVar[int]
    type_name: str
    encoding: str
    raw_file_contents: str
    def __init__(self, type_name: _Optional[str] = ..., encoding: _Optional[str] = ..., raw_file_contents: _Optional[str] = ...) -> None: ...



from make87_messages_ros2.jazzy.geometry_msgs.msg import vector3_pb2 as _vector3_pb2
from google.protobuf import descriptor as _descriptor
from google.protobuf import message as _message
from typing import ClassVar as _ClassVar, Mapping as _Mapping, Optional as _Optional, Union as _Union

DESCRIPTOR: _descriptor.FileDescriptor

class SetPayloadRequest(_message.Message):
    __slots__ = ["mass", "center_of_gravity"]
    MASS_FIELD_NUMBER: _ClassVar[int]
    CENTER_OF_GRAVITY_FIELD_NUMBER: _ClassVar[int]
    mass: float
    center_of_gravity: _vector3_pb2.Vector3
    def __init__(self, mass: _Optional[float] = ..., center_of_gravity: _Optional[_Union[_vector3_pb2.Vector3, _Mapping]] = ...) -> None: ...

class SetPayloadResponse(_message.Message):
    __slots__ = ["success"]
    SUCCESS_FIELD_NUMBER: _ClassVar[int]
    success: bool
    def __init__(self, success: bool = ...) -> None: ...



# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: make87_messages_ros2/rolling/sick_safetyscanners2_interfaces/msg/derived_values.proto
"""Generated protocol buffer code."""
from google.protobuf.internal import builder as _builder
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import symbol_database as _symbol_database
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()




DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\nUmake87_messages_ros2/rolling/sick_safetyscanners2_interfaces/msg/derived_values.proto\x12@make87_messages_ros2.rolling.sick_safetyscanners2_interfaces.msg\"\xaa\x01\n\rDerivedValues\x12\x1d\n\x15multiplication_factor\x18\x01 \x01(\r\x12\x17\n\x0fnumber_of_beams\x18\x02 \x01(\r\x12\x11\n\tscan_time\x18\x03 \x01(\r\x12\x13\n\x0bstart_angle\x18\x04 \x01(\x02\x12\x1f\n\x17\x61ngular_beam_resolution\x18\x05 \x01(\x02\x12\x18\n\x10interbeam_period\x18\x06 \x01(\rb\x06proto3')

_globals = globals()
_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, _globals)
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'make87_messages_ros2.rolling.sick_safetyscanners2_interfaces.msg.derived_values_pb2', _globals)
if _descriptor._USE_C_DESCRIPTORS == False:

  DESCRIPTOR._options = None
  _globals['_DERIVEDVALUES']._serialized_start=156
  _globals['_DERIVEDVALUES']._serialized_end=326
# @@protoc_insertion_point(module_scope)



from make87_messages.core import header_pb2 as _header_pb2
from google.protobuf.internal import containers as _containers
from google.protobuf import descriptor as _descriptor
from google.protobuf import message as _message
from typing import ClassVar as _ClassVar, Iterable as _Iterable, Mapping as _Mapping, Optional as _Optional, Union as _Union

DESCRIPTOR: _descriptor.FileDescriptor

class SPLSM(_message.Message):
    __slots__ = ["header", "player_num", "team_num", "fallen", "pose", "ball_age", "ball", "data"]
    HEADER_FIELD_NUMBER: _ClassVar[int]
    PLAYER_NUM_FIELD_NUMBER: _ClassVar[int]
    TEAM_NUM_FIELD_NUMBER: _ClassVar[int]
    FALLEN_FIELD_NUMBER: _ClassVar[int]
    POSE_FIELD_NUMBER: _ClassVar[int]
    BALL_AGE_FIELD_NUMBER: _ClassVar[int]
    BALL_FIELD_NUMBER: _ClassVar[int]
    DATA_FIELD_NUMBER: _ClassVar[int]
    header: _header_pb2.Header
    player_num: int
    team_num: int
    fallen: int
    pose: _containers.RepeatedScalarFieldContainer[float]
    ball_age: float
    ball: _containers.RepeatedScalarFieldContainer[float]
    data: _containers.RepeatedScalarFieldContainer[int]
    def __init__(self, header: _Optional[_Union[_header_pb2.Header, _Mapping]] = ..., player_num: _Optional[int] = ..., team_num: _Optional[int] = ..., fallen: _Optional[int] = ..., pose: _Optional[_Iterable[float]] = ..., ball_age: _Optional[float] = ..., ball: _Optional[_Iterable[float]] = ..., data: _Optional[_Iterable[int]] = ...) -> None: ...



from make87_messages_ros2.jazzy.lifecycle_msgs.msg import state_pb2 as _state_pb2
from make87_messages_ros2.jazzy.lifecycle_msgs.msg import transition_pb2 as _transition_pb2
from google.protobuf import descriptor as _descriptor
from google.protobuf import message as _message
from typing import ClassVar as _ClassVar, Mapping as _Mapping, Optional as _Optional, Union as _Union

DESCRIPTOR: _descriptor.FileDescriptor

class TransitionDescription(_message.Message):
    __slots__ = ["transition", "start_state", "goal_state"]
    TRANSITION_FIELD_NUMBER: _ClassVar[int]
    START_STATE_FIELD_NUMBER: _ClassVar[int]
    GOAL_STATE_FIELD_NUMBER: _ClassVar[int]
    transition: _transition_pb2.Transition
    start_state: _state_pb2.State
    goal_state: _state_pb2.State
    def __init__(self, transition: _Optional[_Union[_transition_pb2.Transition, _Mapping]] = ..., start_state: _Optional[_Union[_state_pb2.State, _Mapping]] = ..., goal_state: _Optional[_Union[_state_pb2.State, _Mapping]] = ...) -> None: ...



from make87_messages_ros2.jazzy.geometry_msgs.msg import vector3_pb2 as _vector3_pb2
from make87_messages_ros2.jazzy.sbg_driver.msg import sbg_mag_status_pb2 as _sbg_mag_status_pb2
from make87_messages_ros2.jazzy.std_msgs.msg import header_pb2 as _header_pb2
from google.protobuf import descriptor as _descriptor
from google.protobuf import message as _message
from typing import ClassVar as _ClassVar, Mapping as _Mapping, Optional as _Optional, Union as _Union

DESCRIPTOR: _descriptor.FileDescriptor

class SbgMag(_message.Message):
    __slots__ = ["header", "time_stamp", "mag", "accel", "status"]
    HEADER_FIELD_NUMBER: _ClassVar[int]
    TIME_STAMP_FIELD_NUMBER: _ClassVar[int]
    MAG_FIELD_NUMBER: _ClassVar[int]
    ACCEL_FIELD_NUMBER: _ClassVar[int]
    STATUS_FIELD_NUMBER: _ClassVar[int]
    header: _header_pb2.Header
    time_stamp: int
    mag: _vector3_pb2.Vector3
    accel: _vector3_pb2.Vector3
    status: _sbg_mag_status_pb2.SbgMagStatus
    def __init__(self, header: _Optional[_Union[_header_pb2.Header, _Mapping]] = ..., time_stamp: _Optional[int] = ..., mag: _Optional[_Union[_vector3_pb2.Vector3, _Mapping]] = ..., accel: _Optional[_Union[_vector3_pb2.Vector3, _Mapping]] = ..., status: _Optional[_Union[_sbg_mag_status_pb2.SbgMagStatus, _Mapping]] = ...) -> None: ...



from make87_messages.core import header_pb2 as _header_pb2
from make87_messages_ros2.humble.geographic_msgs.msg import geo_pose_pb2 as _geo_pose_pb2
from google.protobuf import descriptor as _descriptor
from google.protobuf import message as _message
from typing import ClassVar as _ClassVar, Mapping as _Mapping, Optional as _Optional, Union as _Union

DESCRIPTOR: _descriptor.FileDescriptor

class SetDatumRequest(_message.Message):
    __slots__ = ["header", "geo_pose"]
    HEADER_FIELD_NUMBER: _ClassVar[int]
    GEO_POSE_FIELD_NUMBER: _ClassVar[int]
    header: _header_pb2.Header
    geo_pose: _geo_pose_pb2.GeoPose
    def __init__(self, header: _Optional[_Union[_header_pb2.Header, _Mapping]] = ..., geo_pose: _Optional[_Union[_geo_pose_pb2.GeoPose, _Mapping]] = ...) -> None: ...

class SetDatumResponse(_message.Message):
    __slots__ = ["header"]
    HEADER_FIELD_NUMBER: _ClassVar[int]
    header: _header_pb2.Header
    def __init__(self, header: _Optional[_Union[_header_pb2.Header, _Mapping]] = ...) -> None: ...



# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: make87_messages_ros2/humble/rtabmap_msgs/srv/set_goal.proto
"""Generated protocol buffer code."""
from google.protobuf.internal import builder as _builder
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import symbol_database as _symbol_database
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from make87_messages.core import header_pb2 as make87__messages_dot_core_dot_header__pb2
from make87_messages_ros2.humble.geometry_msgs.msg import pose_pb2 as make87__messages__ros2_dot_humble_dot_geometry__msgs_dot_msg_dot_pose__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n;make87_messages_ros2/humble/rtabmap_msgs/srv/set_goal.proto\x12,make87_messages_ros2.humble.rtabmap_msgs.srv\x1a!make87_messages/core/header.proto\x1a\x38make87_messages_ros2/humble/geometry_msgs/msg/pose.proto\"u\n\x0eSetGoalRequest\x12,\n\x06header\x18\x01 \x01(\x0b\x32\x1c.make87_messages.core.Header\x12\x0f\n\x07node_id\x18\x02 \x01(\x05\x12\x12\n\nnode_label\x18\x03 \x01(\t\x12\x10\n\x08\x66rame_id\x18\x04 \x01(\t\"\xb1\x01\n\x0fSetGoalResponse\x12,\n\x06header\x18\x01 \x01(\x0b\x32\x1c.make87_messages.core.Header\x12\x10\n\x08path_ids\x18\x02 \x03(\x05\x12G\n\npath_poses\x18\x03 \x03(\x0b\x32\x33.make87_messages_ros2.humble.geometry_msgs.msg.Pose\x12\x15\n\rplanning_time\x18\x04 \x01(\x02\x62\x06proto3')

_globals = globals()
_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, _globals)
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'make87_messages_ros2.humble.rtabmap_msgs.srv.set_goal_pb2', _globals)
if _descriptor._USE_C_DESCRIPTORS == False:

  DESCRIPTOR._options = None
  _globals['_SETGOALREQUEST']._serialized_start=202
  _globals['_SETGOALREQUEST']._serialized_end=319
  _globals['_SETGOALRESPONSE']._serialized_start=322
  _globals['_SETGOALRESPONSE']._serialized_end=499
# @@protoc_insertion_point(module_scope)



# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: make87_messages_ros2/humble/soccer_vision_2d_msgs/msg/goalpost.proto
"""Generated protocol buffer code."""
from google.protobuf.internal import builder as _builder
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import symbol_database as _symbol_database
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from make87_messages.core import header_pb2 as make87__messages_dot_core_dot_header__pb2
from make87_messages_ros2.humble.soccer_vision_attribute_msgs.msg import confidence_pb2 as make87__messages__ros2_dot_humble_dot_soccer__vision__attribute__msgs_dot_msg_dot_confidence__pb2
from make87_messages_ros2.humble.soccer_vision_attribute_msgs.msg import goalpost_pb2 as make87__messages__ros2_dot_humble_dot_soccer__vision__attribute__msgs_dot_msg_dot_goalpost__pb2
from make87_messages_ros2.humble.vision_msgs.msg import bounding_box2_d_pb2 as make87__messages__ros2_dot_humble_dot_vision__msgs_dot_msg_dot_bounding__box2__d__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\nDmake87_messages_ros2/humble/soccer_vision_2d_msgs/msg/goalpost.proto\x12\x35make87_messages_ros2.humble.soccer_vision_2d_msgs.msg\x1a!make87_messages/core/header.proto\x1aMmake87_messages_ros2/humble/soccer_vision_attribute_msgs/msg/confidence.proto\x1aKmake87_messages_ros2/humble/soccer_vision_attribute_msgs/msg/goalpost.proto\x1a\x41make87_messages_ros2/humble/vision_msgs/msg/bounding_box2_d.proto\"\xba\x02\n\x08Goalpost\x12,\n\x06header\x18\x01 \x01(\x0b\x32\x1c.make87_messages.core.Header\x12\x46\n\x02\x62\x62\x18\x02 \x01(\x0b\x32:.make87_messages_ros2.humble.vision_msgs.msg.BoundingBox2D\x12Z\n\nattributes\x18\x03 \x01(\x0b\x32\x46.make87_messages_ros2.humble.soccer_vision_attribute_msgs.msg.Goalpost\x12\\\n\nconfidence\x18\x04 \x01(\x0b\x32H.make87_messages_ros2.humble.soccer_vision_attribute_msgs.msg.Confidenceb\x06proto3')

_globals = globals()
_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, _globals)
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'make87_messages_ros2.humble.soccer_vision_2d_msgs.msg.goalpost_pb2', _globals)
if _descriptor._USE_C_DESCRIPTORS == False:

  DESCRIPTOR._options = None
  _globals['_GOALPOST']._serialized_start=386
  _globals['_GOALPOST']._serialized_end=700
# @@protoc_insertion_point(module_scope)



from make87_messages.core import header_pb2 as _header_pb2
from google.protobuf import descriptor as _descriptor
from google.protobuf import message as _message
from typing import ClassVar as _ClassVar, Mapping as _Mapping, Optional as _Optional, Union as _Union

DESCRIPTOR: _descriptor.FileDescriptor

class PtzState(_message.Message):
    __slots__ = ["header", "mode", "pan", "tilt", "zoom"]
    HEADER_FIELD_NUMBER: _ClassVar[int]
    MODE_FIELD_NUMBER: _ClassVar[int]
    PAN_FIELD_NUMBER: _ClassVar[int]
    TILT_FIELD_NUMBER: _ClassVar[int]
    ZOOM_FIELD_NUMBER: _ClassVar[int]
    header: _header_pb2.Header
    mode: int
    pan: float
    tilt: float
    zoom: float
    def __init__(self, header: _Optional[_Union[_header_pb2.Header, _Mapping]] = ..., mode: _Optional[int] = ..., pan: _Optional[float] = ..., tilt: _Optional[float] = ..., zoom: _Optional[float] = ...) -> None: ...



# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: make87_messages_ros2/rolling/turtlebot3_msgs/srv/dqn.proto
"""Generated protocol buffer code."""
from google.protobuf.internal import builder as _builder
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import symbol_database as _symbol_database
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()




DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n:make87_messages_ros2/rolling/turtlebot3_msgs/srv/dqn.proto\x12\x30make87_messages_ros2.rolling.turtlebot3_msgs.srv\"*\n\nDqnRequest\x12\x0e\n\x06\x61\x63tion\x18\x01 \x01(\r\x12\x0c\n\x04init\x18\x02 \x01(\x08\":\n\x0b\x44qnResponse\x12\r\n\x05state\x18\x01 \x03(\x02\x12\x0e\n\x06reward\x18\x02 \x01(\x02\x12\x0c\n\x04\x64one\x18\x03 \x01(\x08\x62\x06proto3')

_globals = globals()
_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, _globals)
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'make87_messages_ros2.rolling.turtlebot3_msgs.srv.dqn_pb2', _globals)
if _descriptor._USE_C_DESCRIPTORS == False:

  DESCRIPTOR._options = None
  _globals['_DQNREQUEST']._serialized_start=112
  _globals['_DQNREQUEST']._serialized_end=154
  _globals['_DQNRESPONSE']._serialized_start=156
  _globals['_DQNRESPONSE']._serialized_end=214
# @@protoc_insertion_point(module_scope)



from make87_messages_ros2.rolling.std_msgs.msg import header_pb2 as _header_pb2
from make87_messages_ros2.rolling.ublox_ubx_msgs.msg import spartn_key_info_pb2 as _spartn_key_info_pb2
from google.protobuf.internal import containers as _containers
from google.protobuf import descriptor as _descriptor
from google.protobuf import message as _message
from typing import ClassVar as _ClassVar, Iterable as _Iterable, Mapping as _Mapping, Optional as _Optional, Union as _Union

DESCRIPTOR: _descriptor.FileDescriptor

class UBXRxmSpartnKey(_message.Message):
    __slots__ = ["header", "version", "num_keys", "reserved0", "key_info", "key_payload"]
    HEADER_FIELD_NUMBER: _ClassVar[int]
    VERSION_FIELD_NUMBER: _ClassVar[int]
    NUM_KEYS_FIELD_NUMBER: _ClassVar[int]
    RESERVED0_FIELD_NUMBER: _ClassVar[int]
    KEY_INFO_FIELD_NUMBER: _ClassVar[int]
    KEY_PAYLOAD_FIELD_NUMBER: _ClassVar[int]
    header: _header_pb2.Header
    version: int
    num_keys: int
    reserved0: _containers.RepeatedScalarFieldContainer[int]
    key_info: _containers.RepeatedCompositeFieldContainer[_spartn_key_info_pb2.SpartnKeyInfo]
    key_payload: _containers.RepeatedScalarFieldContainer[int]
    def __init__(self, header: _Optional[_Union[_header_pb2.Header, _Mapping]] = ..., version: _Optional[int] = ..., num_keys: _Optional[int] = ..., reserved0: _Optional[_Iterable[int]] = ..., key_info: _Optional[_Iterable[_Union[_spartn_key_info_pb2.SpartnKeyInfo, _Mapping]]] = ..., key_payload: _Optional[_Iterable[int]] = ...) -> None: ...



from make87_messages.core import header_pb2 as _header_pb2
from make87_messages_ros2.humble.rmf_task_msgs.msg import dispatch_state_pb2 as _dispatch_state_pb2
from google.protobuf.internal import containers as _containers
from google.protobuf import descriptor as _descriptor
from google.protobuf import message as _message
from typing import ClassVar as _ClassVar, Iterable as _Iterable, Mapping as _Mapping, Optional as _Optional, Union as _Union

DESCRIPTOR: _descriptor.FileDescriptor

class DispatchStates(_message.Message):
    __slots__ = ["header", "active", "finished"]
    HEADER_FIELD_NUMBER: _ClassVar[int]
    ACTIVE_FIELD_NUMBER: _ClassVar[int]
    FINISHED_FIELD_NUMBER: _ClassVar[int]
    header: _header_pb2.Header
    active: _containers.RepeatedCompositeFieldContainer[_dispatch_state_pb2.DispatchState]
    finished: _containers.RepeatedCompositeFieldContainer[_dispatch_state_pb2.DispatchState]
    def __init__(self, header: _Optional[_Union[_header_pb2.Header, _Mapping]] = ..., active: _Optional[_Iterable[_Union[_dispatch_state_pb2.DispatchState, _Mapping]]] = ..., finished: _Optional[_Iterable[_Union[_dispatch_state_pb2.DispatchState, _Mapping]]] = ...) -> None: ...



from make87_messages_ros2.rolling.automotive_navigation_msgs.msg import point_of_interest_pb2 as _point_of_interest_pb2
from make87_messages_ros2.rolling.std_msgs.msg import header_pb2 as _header_pb2
from google.protobuf.internal import containers as _containers
from google.protobuf import descriptor as _descriptor
from google.protobuf import message as _message
from typing import ClassVar as _ClassVar, Iterable as _Iterable, Mapping as _Mapping, Optional as _Optional, Union as _Union

DESCRIPTOR: _descriptor.FileDescriptor

class PointOfInterestArray(_message.Message):
    __slots__ = ["header", "update_num", "point_list"]
    HEADER_FIELD_NUMBER: _ClassVar[int]
    UPDATE_NUM_FIELD_NUMBER: _ClassVar[int]
    POINT_LIST_FIELD_NUMBER: _ClassVar[int]
    header: _header_pb2.Header
    update_num: int
    point_list: _containers.RepeatedCompositeFieldContainer[_point_of_interest_pb2.PointOfInterest]
    def __init__(self, header: _Optional[_Union[_header_pb2.Header, _Mapping]] = ..., update_num: _Optional[int] = ..., point_list: _Optional[_Iterable[_Union[_point_of_interest_pb2.PointOfInterest, _Mapping]]] = ...) -> None: ...



from make87_messages_ros2.jazzy.geometry_msgs.msg import pose_pb2 as _pose_pb2
from make87_messages_ros2.jazzy.geometry_msgs.msg import transform_pb2 as _transform_pb2
from make87_messages_ros2.jazzy.rtabmap_msgs.msg import link_pb2 as _link_pb2
from make87_messages_ros2.jazzy.std_msgs.msg import header_pb2 as _header_pb2
from google.protobuf.internal import containers as _containers
from google.protobuf import descriptor as _descriptor
from google.protobuf import message as _message
from typing import ClassVar as _ClassVar, Iterable as _Iterable, Mapping as _Mapping, Optional as _Optional, Union as _Union

DESCRIPTOR: _descriptor.FileDescriptor

class MapGraph(_message.Message):
    __slots__ = ["header", "map_to_odom", "poses_id", "poses", "links"]
    HEADER_FIELD_NUMBER: _ClassVar[int]
    MAP_TO_ODOM_FIELD_NUMBER: _ClassVar[int]
    POSES_ID_FIELD_NUMBER: _ClassVar[int]
    POSES_FIELD_NUMBER: _ClassVar[int]
    LINKS_FIELD_NUMBER: _ClassVar[int]
    header: _header_pb2.Header
    map_to_odom: _transform_pb2.Transform
    poses_id: _containers.RepeatedScalarFieldContainer[int]
    poses: _containers.RepeatedCompositeFieldContainer[_pose_pb2.Pose]
    links: _containers.RepeatedCompositeFieldContainer[_link_pb2.Link]
    def __init__(self, header: _Optional[_Union[_header_pb2.Header, _Mapping]] = ..., map_to_odom: _Optional[_Union[_transform_pb2.Transform, _Mapping]] = ..., poses_id: _Optional[_Iterable[int]] = ..., poses: _Optional[_Iterable[_Union[_pose_pb2.Pose, _Mapping]]] = ..., links: _Optional[_Iterable[_Union[_link_pb2.Link, _Mapping]]] = ...) -> None: ...



from make87_messages_ros2.jazzy.data_tamer_msgs.msg import schema_pb2 as _schema_pb2
from google.protobuf.internal import containers as _containers
from google.protobuf import descriptor as _descriptor
from google.protobuf import message as _message
from typing import ClassVar as _ClassVar, Iterable as _Iterable, Mapping as _Mapping, Optional as _Optional, Union as _Union

DESCRIPTOR: _descriptor.FileDescriptor

class Schemas(_message.Message):
    __slots__ = ["schemas"]
    SCHEMAS_FIELD_NUMBER: _ClassVar[int]
    schemas: _containers.RepeatedCompositeFieldContainer[_schema_pb2.Schema]
    def __init__(self, schemas: _Optional[_Iterable[_Union[_schema_pb2.Schema, _Mapping]]] = ...) -> None: ...



# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: make87_messages_ros2/rolling/mavros_msgs/msg/estimator_status.proto
"""Generated protocol buffer code."""
from google.protobuf.internal import builder as _builder
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import symbol_database as _symbol_database
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from make87_messages_ros2.rolling.std_msgs.msg import header_pb2 as make87__messages__ros2_dot_rolling_dot_std__msgs_dot_msg_dot_header__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\nCmake87_messages_ros2/rolling/mavros_msgs/msg/estimator_status.proto\x12,make87_messages_ros2.rolling.mavros_msgs.msg\x1a\x36make87_messages_ros2/rolling/std_msgs/msg/header.proto\"\xf8\x03\n\x0f\x45stimatorStatus\x12\x41\n\x06header\x18\x01 \x01(\x0b\x32\x31.make87_messages_ros2.rolling.std_msgs.msg.Header\x12\x1c\n\x14\x61ttitude_status_flag\x18\x02 \x01(\x08\x12\"\n\x1avelocity_horiz_status_flag\x18\x03 \x01(\x08\x12!\n\x19velocity_vert_status_flag\x18\x04 \x01(\x08\x12!\n\x19pos_horiz_rel_status_flag\x18\x05 \x01(\x08\x12!\n\x19pos_horiz_abs_status_flag\x18\x06 \x01(\x08\x12 \n\x18pos_vert_abs_status_flag\x18\x07 \x01(\x08\x12 \n\x18pos_vert_agl_status_flag\x18\x08 \x01(\x08\x12\"\n\x1a\x63onst_pos_mode_status_flag\x18\t \x01(\x08\x12&\n\x1epred_pos_horiz_rel_status_flag\x18\n \x01(\x08\x12&\n\x1epred_pos_horiz_abs_status_flag\x18\x0b \x01(\x08\x12\x1e\n\x16gps_glitch_status_flag\x18\x0c \x01(\x08\x12\x1f\n\x17\x61\x63\x63\x65l_error_status_flag\x18\r \x01(\x08\x62\x06proto3')

_globals = globals()
_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, _globals)
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'make87_messages_ros2.rolling.mavros_msgs.msg.estimator_status_pb2', _globals)
if _descriptor._USE_C_DESCRIPTORS == False:

  DESCRIPTOR._options = None
  _globals['_ESTIMATORSTATUS']._serialized_start=174
  _globals['_ESTIMATORSTATUS']._serialized_end=678
# @@protoc_insertion_point(module_scope)



# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: make87_messages_ros2/jazzy/visualization_msgs/msg/marker.proto
"""Generated protocol buffer code."""
from google.protobuf.internal import builder as _builder
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import symbol_database as _symbol_database
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from make87_messages_ros2.jazzy.builtin_interfaces.msg import duration_pb2 as make87__messages__ros2_dot_jazzy_dot_builtin__interfaces_dot_msg_dot_duration__pb2
from make87_messages_ros2.jazzy.geometry_msgs.msg import point_pb2 as make87__messages__ros2_dot_jazzy_dot_geometry__msgs_dot_msg_dot_point__pb2
from make87_messages_ros2.jazzy.geometry_msgs.msg import pose_pb2 as make87__messages__ros2_dot_jazzy_dot_geometry__msgs_dot_msg_dot_pose__pb2
from make87_messages_ros2.jazzy.geometry_msgs.msg import vector3_pb2 as make87__messages__ros2_dot_jazzy_dot_geometry__msgs_dot_msg_dot_vector3__pb2
from make87_messages_ros2.jazzy.sensor_msgs.msg import compressed_image_pb2 as make87__messages__ros2_dot_jazzy_dot_sensor__msgs_dot_msg_dot_compressed__image__pb2
from make87_messages_ros2.jazzy.std_msgs.msg import color_rgba_pb2 as make87__messages__ros2_dot_jazzy_dot_std__msgs_dot_msg_dot_color__rgba__pb2
from make87_messages_ros2.jazzy.std_msgs.msg import header_pb2 as make87__messages__ros2_dot_jazzy_dot_std__msgs_dot_msg_dot_header__pb2
from make87_messages_ros2.jazzy.visualization_msgs.msg import mesh_file_pb2 as make87__messages__ros2_dot_jazzy_dot_visualization__msgs_dot_msg_dot_mesh__file__pb2
from make87_messages_ros2.jazzy.visualization_msgs.msg import uv_coordinate_pb2 as make87__messages__ros2_dot_jazzy_dot_visualization__msgs_dot_msg_dot_uv__coordinate__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n>make87_messages_ros2/jazzy/visualization_msgs/msg/marker.proto\x12\x31make87_messages_ros2.jazzy.visualization_msgs.msg\x1a@make87_messages_ros2/jazzy/builtin_interfaces/msg/duration.proto\x1a\x38make87_messages_ros2/jazzy/geometry_msgs/msg/point.proto\x1a\x37make87_messages_ros2/jazzy/geometry_msgs/msg/pose.proto\x1a:make87_messages_ros2/jazzy/geometry_msgs/msg/vector3.proto\x1a\x41make87_messages_ros2/jazzy/sensor_msgs/msg/compressed_image.proto\x1a\x38make87_messages_ros2/jazzy/std_msgs/msg/color_rgba.proto\x1a\x34make87_messages_ros2/jazzy/std_msgs/msg/header.proto\x1a\x41make87_messages_ros2/jazzy/visualization_msgs/msg/mesh_file.proto\x1a\x45make87_messages_ros2/jazzy/visualization_msgs/msg/uv_coordinate.proto\"\x93\x07\n\x06Marker\x12?\n\x06header\x18\x01 \x01(\x0b\x32/.make87_messages_ros2.jazzy.std_msgs.msg.Header\x12\n\n\x02ns\x18\x02 \x01(\t\x12\n\n\x02id\x18\x03 \x01(\x05\x12\x0c\n\x04type\x18\x04 \x01(\x05\x12\x0e\n\x06\x61\x63tion\x18\x05 \x01(\x05\x12@\n\x04pose\x18\x06 \x01(\x0b\x32\x32.make87_messages_ros2.jazzy.geometry_msgs.msg.Pose\x12\x44\n\x05scale\x18\x07 \x01(\x0b\x32\x35.make87_messages_ros2.jazzy.geometry_msgs.msg.Vector3\x12\x41\n\x05\x63olor\x18\x08 \x01(\x0b\x32\x32.make87_messages_ros2.jazzy.std_msgs.msg.ColorRGBA\x12M\n\x08lifetime\x18\t \x01(\x0b\x32;.make87_messages_ros2.jazzy.builtin_interfaces.msg.Duration\x12\x14\n\x0c\x66rame_locked\x18\n \x01(\x08\x12\x43\n\x06points\x18\x0b \x03(\x0b\x32\x33.make87_messages_ros2.jazzy.geometry_msgs.msg.Point\x12\x42\n\x06\x63olors\x18\x0c \x03(\x0b\x32\x32.make87_messages_ros2.jazzy.std_msgs.msg.ColorRGBA\x12\x18\n\x10texture_resource\x18\r \x01(\t\x12L\n\x07texture\x18\x0e \x01(\x0b\x32;.make87_messages_ros2.jazzy.sensor_msgs.msg.CompressedImage\x12W\n\x0euv_coordinates\x18\x0f \x03(\x0b\x32?.make87_messages_ros2.jazzy.visualization_msgs.msg.UVCoordinate\x12\x0c\n\x04text\x18\x10 \x01(\t\x12\x15\n\rmesh_resource\x18\x11 \x01(\t\x12N\n\tmesh_file\x18\x12 \x01(\x0b\x32;.make87_messages_ros2.jazzy.visualization_msgs.msg.MeshFile\x12#\n\x1bmesh_use_embedded_materials\x18\x13 \x01(\x08\x62\x06proto3')

_globals = globals()
_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, _globals)
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'make87_messages_ros2.jazzy.visualization_msgs.msg.marker_pb2', _globals)
if _descriptor._USE_C_DESCRIPTORS == False:

  DESCRIPTOR._options = None
  _globals['_MARKER']._serialized_start=676
  _globals['_MARKER']._serialized_end=1591
# @@protoc_insertion_point(module_scope)



from google.protobuf import descriptor as _descriptor
from google.protobuf import message as _message
from typing import ClassVar as _ClassVar, Optional as _Optional

DESCRIPTOR: _descriptor.FileDescriptor

class RobotModeDataMsg(_message.Message):
    __slots__ = ["timestamp", "is_robot_connected", "is_real_robot_enabled", "is_power_on_robot", "is_emergency_stopped", "is_protective_stopped", "is_program_running", "is_program_paused"]
    TIMESTAMP_FIELD_NUMBER: _ClassVar[int]
    IS_ROBOT_CONNECTED_FIELD_NUMBER: _ClassVar[int]
    IS_REAL_ROBOT_ENABLED_FIELD_NUMBER: _ClassVar[int]
    IS_POWER_ON_ROBOT_FIELD_NUMBER: _ClassVar[int]
    IS_EMERGENCY_STOPPED_FIELD_NUMBER: _ClassVar[int]
    IS_PROTECTIVE_STOPPED_FIELD_NUMBER: _ClassVar[int]
    IS_PROGRAM_RUNNING_FIELD_NUMBER: _ClassVar[int]
    IS_PROGRAM_PAUSED_FIELD_NUMBER: _ClassVar[int]
    timestamp: int
    is_robot_connected: bool
    is_real_robot_enabled: bool
    is_power_on_robot: bool
    is_emergency_stopped: bool
    is_protective_stopped: bool
    is_program_running: bool
    is_program_paused: bool
    def __init__(self, timestamp: _Optional[int] = ..., is_robot_connected: bool = ..., is_real_robot_enabled: bool = ..., is_power_on_robot: bool = ..., is_emergency_stopped: bool = ..., is_protective_stopped: bool = ..., is_program_running: bool = ..., is_program_paused: bool = ...) -> None: ...



# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: make87_messages_ros2/jazzy/nav2_msgs/srv/clear_costmap_around_robot.proto
"""Generated protocol buffer code."""
from google.protobuf.internal import builder as _builder
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import symbol_database as _symbol_database
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from make87_messages_ros2.jazzy.std_msgs.msg import empty_pb2 as make87__messages__ros2_dot_jazzy_dot_std__msgs_dot_msg_dot_empty__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\nImake87_messages_ros2/jazzy/nav2_msgs/srv/clear_costmap_around_robot.proto\x12(make87_messages_ros2.jazzy.nav2_msgs.srv\x1a\x33make87_messages_ros2/jazzy/std_msgs/msg/empty.proto\"8\n\x1e\x43learCostmapAroundRobotRequest\x12\x16\n\x0ereset_distance\x18\x01 \x01(\x02\"c\n\x1f\x43learCostmapAroundRobotResponse\x12@\n\x08response\x18\x01 \x01(\x0b\x32..make87_messages_ros2.jazzy.std_msgs.msg.Emptyb\x06proto3')

_globals = globals()
_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, _globals)
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'make87_messages_ros2.jazzy.nav2_msgs.srv.clear_costmap_around_robot_pb2', _globals)
if _descriptor._USE_C_DESCRIPTORS == False:

  DESCRIPTOR._options = None
  _globals['_CLEARCOSTMAPAROUNDROBOTREQUEST']._serialized_start=172
  _globals['_CLEARCOSTMAPAROUNDROBOTREQUEST']._serialized_end=228
  _globals['_CLEARCOSTMAPAROUNDROBOTRESPONSE']._serialized_start=230
  _globals['_CLEARCOSTMAPAROUNDROBOTRESPONSE']._serialized_end=329
# @@protoc_insertion_point(module_scope)



# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: make87_messages_ros2/humble/nav2_msgs/msg/voxel_grid.proto
"""Generated protocol buffer code."""
from google.protobuf.internal import builder as _builder
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import symbol_database as _symbol_database
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from make87_messages.core import header_pb2 as make87__messages_dot_core_dot_header__pb2
from make87_messages_ros2.humble.geometry_msgs.msg import point32_pb2 as make87__messages__ros2_dot_humble_dot_geometry__msgs_dot_msg_dot_point32__pb2
from make87_messages_ros2.humble.geometry_msgs.msg import vector3_pb2 as make87__messages__ros2_dot_humble_dot_geometry__msgs_dot_msg_dot_vector3__pb2
from make87_messages_ros2.humble.std_msgs.msg import header_pb2 as make87__messages__ros2_dot_humble_dot_std__msgs_dot_msg_dot_header__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n:make87_messages_ros2/humble/nav2_msgs/msg/voxel_grid.proto\x12)make87_messages_ros2.humble.nav2_msgs.msg\x1a!make87_messages/core/header.proto\x1a;make87_messages_ros2/humble/geometry_msgs/msg/point32.proto\x1a;make87_messages_ros2/humble/geometry_msgs/msg/vector3.proto\x1a\x35make87_messages_ros2/humble/std_msgs/msg/header.proto\"\xd3\x02\n\tVoxelGrid\x12,\n\x06header\x18\x01 \x01(\x0b\x32\x1c.make87_messages.core.Header\x12\x45\n\x0bros2_header\x18\x02 \x01(\x0b\x32\x30.make87_messages_ros2.humble.std_msgs.msg.Header\x12\x0c\n\x04\x64\x61ta\x18\x03 \x03(\r\x12\x46\n\x06origin\x18\x04 \x01(\x0b\x32\x36.make87_messages_ros2.humble.geometry_msgs.msg.Point32\x12K\n\x0bresolutions\x18\x05 \x01(\x0b\x32\x36.make87_messages_ros2.humble.geometry_msgs.msg.Vector3\x12\x0e\n\x06size_x\x18\x06 \x01(\r\x12\x0e\n\x06size_y\x18\x07 \x01(\r\x12\x0e\n\x06size_z\x18\x08 \x01(\rb\x06proto3')

_globals = globals()
_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, _globals)
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'make87_messages_ros2.humble.nav2_msgs.msg.voxel_grid_pb2', _globals)
if _descriptor._USE_C_DESCRIPTORS == False:

  DESCRIPTOR._options = None
  _globals['_VOXELGRID']._serialized_start=318
  _globals['_VOXELGRID']._serialized_end=657
# @@protoc_insertion_point(module_scope)



# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: make87_messages_ros2/rolling/webots_ros2_msgs/srv/emitter_send_string.proto
"""Generated protocol buffer code."""
from google.protobuf.internal import builder as _builder
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import symbol_database as _symbol_database
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()




DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\nKmake87_messages_ros2/rolling/webots_ros2_msgs/srv/emitter_send_string.proto\x12\x31make87_messages_ros2.rolling.webots_ros2_msgs.srv\")\n\x18\x45mitterSendStringRequest\x12\r\n\x05value\x18\x01 \x01(\t\"+\n\x19\x45mitterSendStringResponse\x12\x0e\n\x06result\x18\x01 \x01(\x03\x62\x06proto3')

_globals = globals()
_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, _globals)
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'make87_messages_ros2.rolling.webots_ros2_msgs.srv.emitter_send_string_pb2', _globals)
if _descriptor._USE_C_DESCRIPTORS == False:

  DESCRIPTOR._options = None
  _globals['_EMITTERSENDSTRINGREQUEST']._serialized_start=130
  _globals['_EMITTERSENDSTRINGREQUEST']._serialized_end=171
  _globals['_EMITTERSENDSTRINGRESPONSE']._serialized_start=173
  _globals['_EMITTERSENDSTRINGRESPONSE']._serialized_end=216
# @@protoc_insertion_point(module_scope)



# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: make87_messages_ros2/rolling/rmf_ingestor_msgs/msg/ingestor_request.proto
"""Generated protocol buffer code."""
from google.protobuf.internal import builder as _builder
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import symbol_database as _symbol_database
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from make87_messages_ros2.rolling.builtin_interfaces.msg import time_pb2 as make87__messages__ros2_dot_rolling_dot_builtin__interfaces_dot_msg_dot_time__pb2
from make87_messages_ros2.rolling.rmf_ingestor_msgs.msg import ingestor_request_item_pb2 as make87__messages__ros2_dot_rolling_dot_rmf__ingestor__msgs_dot_msg_dot_ingestor__request__item__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\nImake87_messages_ros2/rolling/rmf_ingestor_msgs/msg/ingestor_request.proto\x12\x32make87_messages_ros2.rolling.rmf_ingestor_msgs.msg\x1a>make87_messages_ros2/rolling/builtin_interfaces/msg/time.proto\x1aNmake87_messages_ros2/rolling/rmf_ingestor_msgs/msg/ingestor_request_item.proto\"\xf7\x01\n\x0fIngestorRequest\x12G\n\x04time\x18\x01 \x01(\x0b\x32\x39.make87_messages_ros2.rolling.builtin_interfaces.msg.Time\x12\x14\n\x0crequest_guid\x18\x02 \x01(\t\x12\x13\n\x0btarget_guid\x18\x03 \x01(\t\x12\x18\n\x10transporter_type\x18\x04 \x01(\t\x12V\n\x05items\x18\x05 \x03(\x0b\x32G.make87_messages_ros2.rolling.rmf_ingestor_msgs.msg.IngestorRequestItemb\x06proto3')

_globals = globals()
_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, _globals)
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'make87_messages_ros2.rolling.rmf_ingestor_msgs.msg.ingestor_request_pb2', _globals)
if _descriptor._USE_C_DESCRIPTORS == False:

  DESCRIPTOR._options = None
  _globals['_INGESTORREQUEST']._serialized_start=274
  _globals['_INGESTORREQUEST']._serialized_end=521
# @@protoc_insertion_point(module_scope)



from make87_messages_ros2.jazzy.plansys2_msgs.msg import plan_item_pb2 as _plan_item_pb2
from google.protobuf.internal import containers as _containers
from google.protobuf import descriptor as _descriptor
from google.protobuf import message as _message
from typing import ClassVar as _ClassVar, Iterable as _Iterable, Mapping as _Mapping, Optional as _Optional, Union as _Union

DESCRIPTOR: _descriptor.FileDescriptor

class Plan(_message.Message):
    __slots__ = ["items"]
    ITEMS_FIELD_NUMBER: _ClassVar[int]
    items: _containers.RepeatedCompositeFieldContainer[_plan_item_pb2.PlanItem]
    def __init__(self, items: _Optional[_Iterable[_Union[_plan_item_pb2.PlanItem, _Mapping]]] = ...) -> None: ...



from make87_messages_ros2.rolling.rcl_interfaces.msg import logger_level_pb2 as _logger_level_pb2
from make87_messages_ros2.rolling.rcl_interfaces.msg import set_logger_levels_result_pb2 as _set_logger_levels_result_pb2
from google.protobuf.internal import containers as _containers
from google.protobuf import descriptor as _descriptor
from google.protobuf import message as _message
from typing import ClassVar as _ClassVar, Iterable as _Iterable, Mapping as _Mapping, Optional as _Optional, Union as _Union

DESCRIPTOR: _descriptor.FileDescriptor

class SetLoggerLevelsRequest(_message.Message):
    __slots__ = ["levels"]
    LEVELS_FIELD_NUMBER: _ClassVar[int]
    levels: _containers.RepeatedCompositeFieldContainer[_logger_level_pb2.LoggerLevel]
    def __init__(self, levels: _Optional[_Iterable[_Union[_logger_level_pb2.LoggerLevel, _Mapping]]] = ...) -> None: ...

class SetLoggerLevelsResponse(_message.Message):
    __slots__ = ["results"]
    RESULTS_FIELD_NUMBER: _ClassVar[int]
    results: _containers.RepeatedCompositeFieldContainer[_set_logger_levels_result_pb2.SetLoggerLevelsResult]
    def __init__(self, results: _Optional[_Iterable[_Union[_set_logger_levels_result_pb2.SetLoggerLevelsResult, _Mapping]]] = ...) -> None: ...



# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: make87_messages_ros2/rolling/irobot_create_msgs/msg/button.proto
"""Generated protocol buffer code."""
from google.protobuf.internal import builder as _builder
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import symbol_database as _symbol_database
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from make87_messages_ros2.rolling.builtin_interfaces.msg import duration_pb2 as make87__messages__ros2_dot_rolling_dot_builtin__interfaces_dot_msg_dot_duration__pb2
from make87_messages_ros2.rolling.builtin_interfaces.msg import time_pb2 as make87__messages__ros2_dot_rolling_dot_builtin__interfaces_dot_msg_dot_time__pb2
from make87_messages_ros2.rolling.std_msgs.msg import header_pb2 as make87__messages__ros2_dot_rolling_dot_std__msgs_dot_msg_dot_header__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n@make87_messages_ros2/rolling/irobot_create_msgs/msg/button.proto\x12\x33make87_messages_ros2.rolling.irobot_create_msgs.msg\x1a\x42make87_messages_ros2/rolling/builtin_interfaces/msg/duration.proto\x1a>make87_messages_ros2/rolling/builtin_interfaces/msg/time.proto\x1a\x36make87_messages_ros2/rolling/std_msgs/msg/header.proto\"\x99\x02\n\x06\x42utton\x12\x41\n\x06header\x18\x01 \x01(\x0b\x32\x31.make87_messages_ros2.rolling.std_msgs.msg.Header\x12\x12\n\nis_pressed\x18\x02 \x01(\x08\x12Z\n\x17last_start_pressed_time\x18\x03 \x01(\x0b\x32\x39.make87_messages_ros2.rolling.builtin_interfaces.msg.Time\x12\\\n\x15last_pressed_duration\x18\x04 \x01(\x0b\x32=.make87_messages_ros2.rolling.builtin_interfaces.msg.Durationb\x06proto3')

_globals = globals()
_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, _globals)
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'make87_messages_ros2.rolling.irobot_create_msgs.msg.button_pb2', _globals)
if _descriptor._USE_C_DESCRIPTORS == False:

  DESCRIPTOR._options = None
  _globals['_BUTTON']._serialized_start=310
  _globals['_BUTTON']._serialized_end=591
# @@protoc_insertion_point(module_scope)



# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: make87_messages_ros2/jazzy/autoware_map_msgs/srv/get_partial_point_cloud_map.proto
"""Generated protocol buffer code."""
from google.protobuf.internal import builder as _builder
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import symbol_database as _symbol_database
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from make87_messages_ros2.jazzy.autoware_map_msgs.msg import area_info_pb2 as make87__messages__ros2_dot_jazzy_dot_autoware__map__msgs_dot_msg_dot_area__info__pb2
from make87_messages_ros2.jazzy.autoware_map_msgs.msg import point_cloud_map_cell_with_id_pb2 as make87__messages__ros2_dot_jazzy_dot_autoware__map__msgs_dot_msg_dot_point__cloud__map__cell__with__id__pb2
from make87_messages_ros2.jazzy.std_msgs.msg import header_pb2 as make87__messages__ros2_dot_jazzy_dot_std__msgs_dot_msg_dot_header__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\nRmake87_messages_ros2/jazzy/autoware_map_msgs/srv/get_partial_point_cloud_map.proto\x12\x30make87_messages_ros2.jazzy.autoware_map_msgs.srv\x1a@make87_messages_ros2/jazzy/autoware_map_msgs/msg/area_info.proto\x1aSmake87_messages_ros2/jazzy/autoware_map_msgs/msg/point_cloud_map_cell_with_id.proto\x1a\x34make87_messages_ros2/jazzy/std_msgs/msg/header.proto\"j\n\x1eGetPartialPointCloudMapRequest\x12H\n\x04\x61rea\x18\x01 \x01(\x0b\x32:.make87_messages_ros2.jazzy.autoware_map_msgs.msg.AreaInfo\"\xce\x01\n\x1fGetPartialPointCloudMapResponse\x12?\n\x06header\x18\x01 \x01(\x0b\x32/.make87_messages_ros2.jazzy.std_msgs.msg.Header\x12j\n\x17new_pointcloud_with_ids\x18\x02 \x03(\x0b\x32I.make87_messages_ros2.jazzy.autoware_map_msgs.msg.PointCloudMapCellWithIDb\x06proto3')

_globals = globals()
_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, _globals)
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'make87_messages_ros2.jazzy.autoware_map_msgs.srv.get_partial_point_cloud_map_pb2', _globals)
if _descriptor._USE_C_DESCRIPTORS == False:

  DESCRIPTOR._options = None
  _globals['_GETPARTIALPOINTCLOUDMAPREQUEST']._serialized_start=341
  _globals['_GETPARTIALPOINTCLOUDMAPREQUEST']._serialized_end=447
  _globals['_GETPARTIALPOINTCLOUDMAPRESPONSE']._serialized_start=450
  _globals['_GETPARTIALPOINTCLOUDMAPRESPONSE']._serialized_end=656
# @@protoc_insertion_point(module_scope)



from make87_messages_ros2.jazzy.novatel_gps_msgs.msg import novatel_extended_solution_status_pb2 as _novatel_extended_solution_status_pb2
from make87_messages_ros2.jazzy.novatel_gps_msgs.msg import novatel_message_header_pb2 as _novatel_message_header_pb2
from make87_messages_ros2.jazzy.std_msgs.msg import header_pb2 as _header_pb2
from google.protobuf import descriptor as _descriptor
from google.protobuf import message as _message
from typing import ClassVar as _ClassVar, Mapping as _Mapping, Optional as _Optional, Union as _Union

DESCRIPTOR: _descriptor.FileDescriptor

class Inspvax(_message.Message):
    __slots__ = ["header", "novatel_msg_header", "ins_status", "position_type", "latitude", "longitude", "altitude", "undulation", "north_velocity", "east_velocity", "up_velocity", "roll", "pitch", "azimuth", "latitude_std", "longitude_std", "altitude_std", "north_velocity_std", "east_velocity_std", "up_velocity_std", "roll_std", "pitch_std", "azimuth_std", "extended_status", "seconds_since_update"]
    HEADER_FIELD_NUMBER: _ClassVar[int]
    NOVATEL_MSG_HEADER_FIELD_NUMBER: _ClassVar[int]
    INS_STATUS_FIELD_NUMBER: _ClassVar[int]
    POSITION_TYPE_FIELD_NUMBER: _ClassVar[int]
    LATITUDE_FIELD_NUMBER: _ClassVar[int]
    LONGITUDE_FIELD_NUMBER: _ClassVar[int]
    ALTITUDE_FIELD_NUMBER: _ClassVar[int]
    UNDULATION_FIELD_NUMBER: _ClassVar[int]
    NORTH_VELOCITY_FIELD_NUMBER: _ClassVar[int]
    EAST_VELOCITY_FIELD_NUMBER: _ClassVar[int]
    UP_VELOCITY_FIELD_NUMBER: _ClassVar[int]
    ROLL_FIELD_NUMBER: _ClassVar[int]
    PITCH_FIELD_NUMBER: _ClassVar[int]
    AZIMUTH_FIELD_NUMBER: _ClassVar[int]
    LATITUDE_STD_FIELD_NUMBER: _ClassVar[int]
    LONGITUDE_STD_FIELD_NUMBER: _ClassVar[int]
    ALTITUDE_STD_FIELD_NUMBER: _ClassVar[int]
    NORTH_VELOCITY_STD_FIELD_NUMBER: _ClassVar[int]
    EAST_VELOCITY_STD_FIELD_NUMBER: _ClassVar[int]
    UP_VELOCITY_STD_FIELD_NUMBER: _ClassVar[int]
    ROLL_STD_FIELD_NUMBER: _ClassVar[int]
    PITCH_STD_FIELD_NUMBER: _ClassVar[int]
    AZIMUTH_STD_FIELD_NUMBER: _ClassVar[int]
    EXTENDED_STATUS_FIELD_NUMBER: _ClassVar[int]
    SECONDS_SINCE_UPDATE_FIELD_NUMBER: _ClassVar[int]
    header: _header_pb2.Header
    novatel_msg_header: _novatel_message_header_pb2.NovatelMessageHeader
    ins_status: str
    position_type: str
    latitude: float
    longitude: float
    altitude: float
    undulation: float
    north_velocity: float
    east_velocity: float
    up_velocity: float
    roll: float
    pitch: float
    azimuth: float
    latitude_std: float
    longitude_std: float
    altitude_std: float
    north_velocity_std: float
    east_velocity_std: float
    up_velocity_std: float
    roll_std: float
    pitch_std: float
    azimuth_std: float
    extended_status: _novatel_extended_solution_status_pb2.NovatelExtendedSolutionStatus
    seconds_since_update: int
    def __init__(self, header: _Optional[_Union[_header_pb2.Header, _Mapping]] = ..., novatel_msg_header: _Optional[_Union[_novatel_message_header_pb2.NovatelMessageHeader, _Mapping]] = ..., ins_status: _Optional[str] = ..., position_type: _Optional[str] = ..., latitude: _Optional[float] = ..., longitude: _Optional[float] = ..., altitude: _Optional[float] = ..., undulation: _Optional[float] = ..., north_velocity: _Optional[float] = ..., east_velocity: _Optional[float] = ..., up_velocity: _Optional[float] = ..., roll: _Optional[float] = ..., pitch: _Optional[float] = ..., azimuth: _Optional[float] = ..., latitude_std: _Optional[float] = ..., longitude_std: _Optional[float] = ..., altitude_std: _Optional[float] = ..., north_velocity_std: _Optional[float] = ..., east_velocity_std: _Optional[float] = ..., up_velocity_std: _Optional[float] = ..., roll_std: _Optional[float] = ..., pitch_std: _Optional[float] = ..., azimuth_std: _Optional[float] = ..., extended_status: _Optional[_Union[_novatel_extended_solution_status_pb2.NovatelExtendedSolutionStatus, _Mapping]] = ..., seconds_since_update: _Optional[int] = ...) -> None: ...



from make87_messages_ros2.jazzy.ros_gz_interfaces.msg import entity_pb2 as _entity_pb2
from make87_messages_ros2.jazzy.std_msgs.msg import color_rgba_pb2 as _color_rgba_pb2
from make87_messages_ros2.jazzy.std_msgs.msg import header_pb2 as _header_pb2
from google.protobuf import descriptor as _descriptor
from google.protobuf import message as _message
from typing import ClassVar as _ClassVar, Mapping as _Mapping, Optional as _Optional, Union as _Union

DESCRIPTOR: _descriptor.FileDescriptor

class MaterialColor(_message.Message):
    __slots__ = ["header", "entity", "ambient", "diffuse", "specular", "emissive", "shininess", "entity_match"]
    HEADER_FIELD_NUMBER: _ClassVar[int]
    ENTITY_FIELD_NUMBER: _ClassVar[int]
    AMBIENT_FIELD_NUMBER: _ClassVar[int]
    DIFFUSE_FIELD_NUMBER: _ClassVar[int]
    SPECULAR_FIELD_NUMBER: _ClassVar[int]
    EMISSIVE_FIELD_NUMBER: _ClassVar[int]
    SHININESS_FIELD_NUMBER: _ClassVar[int]
    ENTITY_MATCH_FIELD_NUMBER: _ClassVar[int]
    header: _header_pb2.Header
    entity: _entity_pb2.Entity
    ambient: _color_rgba_pb2.ColorRGBA
    diffuse: _color_rgba_pb2.ColorRGBA
    specular: _color_rgba_pb2.ColorRGBA
    emissive: _color_rgba_pb2.ColorRGBA
    shininess: float
    entity_match: int
    def __init__(self, header: _Optional[_Union[_header_pb2.Header, _Mapping]] = ..., entity: _Optional[_Union[_entity_pb2.Entity, _Mapping]] = ..., ambient: _Optional[_Union[_color_rgba_pb2.ColorRGBA, _Mapping]] = ..., diffuse: _Optional[_Union[_color_rgba_pb2.ColorRGBA, _Mapping]] = ..., specular: _Optional[_Union[_color_rgba_pb2.ColorRGBA, _Mapping]] = ..., emissive: _Optional[_Union[_color_rgba_pb2.ColorRGBA, _Mapping]] = ..., shininess: _Optional[float] = ..., entity_match: _Optional[int] = ...) -> None: ...



from make87_messages.core import header_pb2 as _header_pb2
from google.protobuf import descriptor as _descriptor
from google.protobuf import message as _message
from typing import ClassVar as _ClassVar, Mapping as _Mapping, Optional as _Optional, Union as _Union

DESCRIPTOR: _descriptor.FileDescriptor

class LiftClearanceRequest(_message.Message):
    __slots__ = ["header", "robot_name", "lift_name"]
    HEADER_FIELD_NUMBER: _ClassVar[int]
    ROBOT_NAME_FIELD_NUMBER: _ClassVar[int]
    LIFT_NAME_FIELD_NUMBER: _ClassVar[int]
    header: _header_pb2.Header
    robot_name: str
    lift_name: str
    def __init__(self, header: _Optional[_Union[_header_pb2.Header, _Mapping]] = ..., robot_name: _Optional[str] = ..., lift_name: _Optional[str] = ...) -> None: ...

class LiftClearanceResponse(_message.Message):
    __slots__ = ["header", "decision"]
    HEADER_FIELD_NUMBER: _ClassVar[int]
    DECISION_FIELD_NUMBER: _ClassVar[int]
    header: _header_pb2.Header
    decision: int
    def __init__(self, header: _Optional[_Union[_header_pb2.Header, _Mapping]] = ..., decision: _Optional[int] = ...) -> None: ...



# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: make87_messages_ros2/jazzy/action_msgs/srv/cancel_goal.proto
"""Generated protocol buffer code."""
from google.protobuf.internal import builder as _builder
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import symbol_database as _symbol_database
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from make87_messages_ros2.jazzy.action_msgs.msg import goal_info_pb2 as make87__messages__ros2_dot_jazzy_dot_action__msgs_dot_msg_dot_goal__info__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n<make87_messages_ros2/jazzy/action_msgs/srv/cancel_goal.proto\x12*make87_messages_ros2.jazzy.action_msgs.srv\x1a:make87_messages_ros2/jazzy/action_msgs/msg/goal_info.proto\"\\\n\x11\x43\x61ncelGoalRequest\x12G\n\tgoal_info\x18\x01 \x01(\x0b\x32\x34.make87_messages_ros2.jazzy.action_msgs.msg.GoalInfo\"x\n\x12\x43\x61ncelGoalResponse\x12\x13\n\x0breturn_code\x18\x01 \x01(\x05\x12M\n\x0fgoals_canceling\x18\x02 \x03(\x0b\x32\x34.make87_messages_ros2.jazzy.action_msgs.msg.GoalInfob\x06proto3')

_globals = globals()
_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, _globals)
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'make87_messages_ros2.jazzy.action_msgs.srv.cancel_goal_pb2', _globals)
if _descriptor._USE_C_DESCRIPTORS == False:

  DESCRIPTOR._options = None
  _globals['_CANCELGOALREQUEST']._serialized_start=168
  _globals['_CANCELGOALREQUEST']._serialized_end=260
  _globals['_CANCELGOALRESPONSE']._serialized_start=262
  _globals['_CANCELGOALRESPONSE']._serialized_end=382
# @@protoc_insertion_point(module_scope)



from make87_messages.core import header_pb2 as _header_pb2
from google.protobuf import descriptor as _descriptor
from google.protobuf import message as _message
from typing import ClassVar as _ClassVar, Mapping as _Mapping, Optional as _Optional, Union as _Union

DESCRIPTOR: _descriptor.FileDescriptor

class CommandLongRequest(_message.Message):
    __slots__ = ["header", "broadcast", "command", "confirmation", "param1", "param2", "param3", "param4", "param5", "param6", "param7"]
    HEADER_FIELD_NUMBER: _ClassVar[int]
    BROADCAST_FIELD_NUMBER: _ClassVar[int]
    COMMAND_FIELD_NUMBER: _ClassVar[int]
    CONFIRMATION_FIELD_NUMBER: _ClassVar[int]
    PARAM1_FIELD_NUMBER: _ClassVar[int]
    PARAM2_FIELD_NUMBER: _ClassVar[int]
    PARAM3_FIELD_NUMBER: _ClassVar[int]
    PARAM4_FIELD_NUMBER: _ClassVar[int]
    PARAM5_FIELD_NUMBER: _ClassVar[int]
    PARAM6_FIELD_NUMBER: _ClassVar[int]
    PARAM7_FIELD_NUMBER: _ClassVar[int]
    header: _header_pb2.Header
    broadcast: bool
    command: int
    confirmation: int
    param1: float
    param2: float
    param3: float
    param4: float
    param5: float
    param6: float
    param7: float
    def __init__(self, header: _Optional[_Union[_header_pb2.Header, _Mapping]] = ..., broadcast: bool = ..., command: _Optional[int] = ..., confirmation: _Optional[int] = ..., param1: _Optional[float] = ..., param2: _Optional[float] = ..., param3: _Optional[float] = ..., param4: _Optional[float] = ..., param5: _Optional[float] = ..., param6: _Optional[float] = ..., param7: _Optional[float] = ...) -> None: ...

class CommandLongResponse(_message.Message):
    __slots__ = ["header", "success", "result"]
    HEADER_FIELD_NUMBER: _ClassVar[int]
    SUCCESS_FIELD_NUMBER: _ClassVar[int]
    RESULT_FIELD_NUMBER: _ClassVar[int]
    header: _header_pb2.Header
    success: bool
    result: int
    def __init__(self, header: _Optional[_Union[_header_pb2.Header, _Mapping]] = ..., success: bool = ..., result: _Optional[int] = ...) -> None: ...



from make87_messages_ros2.jazzy.soccer_vision_attribute_msgs.msg import confidence_pb2 as _confidence_pb2
from make87_messages_ros2.jazzy.std_msgs.msg import header_pb2 as _header_pb2
from make87_messages_ros2.jazzy.vision_msgs.msg import point2_d_pb2 as _point2_d_pb2
from google.protobuf.internal import containers as _containers
from google.protobuf import descriptor as _descriptor
from google.protobuf import message as _message
from typing import ClassVar as _ClassVar, Iterable as _Iterable, Mapping as _Mapping, Optional as _Optional, Union as _Union

DESCRIPTOR: _descriptor.FileDescriptor

class FieldBoundary(_message.Message):
    __slots__ = ["header", "points", "confidence"]
    HEADER_FIELD_NUMBER: _ClassVar[int]
    POINTS_FIELD_NUMBER: _ClassVar[int]
    CONFIDENCE_FIELD_NUMBER: _ClassVar[int]
    header: _header_pb2.Header
    points: _containers.RepeatedCompositeFieldContainer[_point2_d_pb2.Point2D]
    confidence: _confidence_pb2.Confidence
    def __init__(self, header: _Optional[_Union[_header_pb2.Header, _Mapping]] = ..., points: _Optional[_Iterable[_Union[_point2_d_pb2.Point2D, _Mapping]]] = ..., confidence: _Optional[_Union[_confidence_pb2.Confidence, _Mapping]] = ...) -> None: ...



# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: make87_messages_ros2/jazzy/mavros_msgs/msg/camera_image_captured.proto
"""Generated protocol buffer code."""
from google.protobuf.internal import builder as _builder
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import symbol_database as _symbol_database
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from make87_messages_ros2.jazzy.geographic_msgs.msg import geo_point_pb2 as make87__messages__ros2_dot_jazzy_dot_geographic__msgs_dot_msg_dot_geo__point__pb2
from make87_messages_ros2.jazzy.geometry_msgs.msg import quaternion_pb2 as make87__messages__ros2_dot_jazzy_dot_geometry__msgs_dot_msg_dot_quaternion__pb2
from make87_messages_ros2.jazzy.std_msgs.msg import header_pb2 as make87__messages__ros2_dot_jazzy_dot_std__msgs_dot_msg_dot_header__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\nFmake87_messages_ros2/jazzy/mavros_msgs/msg/camera_image_captured.proto\x12*make87_messages_ros2.jazzy.mavros_msgs.msg\x1a>make87_messages_ros2/jazzy/geographic_msgs/msg/geo_point.proto\x1a=make87_messages_ros2/jazzy/geometry_msgs/msg/quaternion.proto\x1a\x34make87_messages_ros2/jazzy/std_msgs/msg/header.proto\"\xc1\x02\n\x13\x43\x61meraImageCaptured\x12?\n\x06header\x18\x01 \x01(\x0b\x32/.make87_messages_ros2.jazzy.std_msgs.msg.Header\x12M\n\x0borientation\x18\x02 \x01(\x0b\x32\x38.make87_messages_ros2.jazzy.geometry_msgs.msg.Quaternion\x12\x45\n\x03geo\x18\x03 \x01(\x0b\x32\x38.make87_messages_ros2.jazzy.geographic_msgs.msg.GeoPoint\x12\x14\n\x0crelative_alt\x18\x04 \x01(\x02\x12\x13\n\x0bimage_index\x18\x05 \x01(\x05\x12\x16\n\x0e\x63\x61pture_result\x18\x06 \x01(\x05\x12\x10\n\x08\x66ile_url\x18\x07 \x01(\tb\x06proto3')

_globals = globals()
_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, _globals)
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'make87_messages_ros2.jazzy.mavros_msgs.msg.camera_image_captured_pb2', _globals)
if _descriptor._USE_C_DESCRIPTORS == False:

  DESCRIPTOR._options = None
  _globals['_CAMERAIMAGECAPTURED']._serialized_start=300
  _globals['_CAMERAIMAGECAPTURED']._serialized_end=621
# @@protoc_insertion_point(module_scope)



# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: make87_messages_ros2/jazzy/rmf_task_msgs/msg/dispatch_state.proto
"""Generated protocol buffer code."""
from google.protobuf.internal import builder as _builder
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import symbol_database as _symbol_database
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from make87_messages_ros2.jazzy.rmf_task_msgs.msg import assignment_pb2 as make87__messages__ros2_dot_jazzy_dot_rmf__task__msgs_dot_msg_dot_assignment__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\nAmake87_messages_ros2/jazzy/rmf_task_msgs/msg/dispatch_state.proto\x12,make87_messages_ros2.jazzy.rmf_task_msgs.msg\x1a=make87_messages_ros2/jazzy/rmf_task_msgs/msg/assignment.proto\"\x8e\x01\n\rDispatchState\x12\x0f\n\x07task_id\x18\x01 \x01(\t\x12\x0e\n\x06status\x18\x02 \x01(\x05\x12L\n\nassignment\x18\x03 \x01(\x0b\x32\x38.make87_messages_ros2.jazzy.rmf_task_msgs.msg.Assignment\x12\x0e\n\x06\x65rrors\x18\x04 \x03(\tb\x06proto3')

_globals = globals()
_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, _globals)
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'make87_messages_ros2.jazzy.rmf_task_msgs.msg.dispatch_state_pb2', _globals)
if _descriptor._USE_C_DESCRIPTORS == False:

  DESCRIPTOR._options = None
  _globals['_DISPATCHSTATE']._serialized_start=179
  _globals['_DISPATCHSTATE']._serialized_end=321
# @@protoc_insertion_point(module_scope)



# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: make87_messages_ros2/humble/map_msgs/msg/projected_map_info.proto
"""Generated protocol buffer code."""
from google.protobuf.internal import builder as _builder
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import symbol_database as _symbol_database
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from make87_messages.core import header_pb2 as make87__messages_dot_core_dot_header__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\nAmake87_messages_ros2/humble/map_msgs/msg/projected_map_info.proto\x12(make87_messages_ros2.humble.map_msgs.msg\x1a!make87_messages/core/header.proto\"\xa5\x01\n\x10ProjectedMapInfo\x12,\n\x06header\x18\x01 \x01(\x0b\x32\x1c.make87_messages.core.Header\x12\x10\n\x08\x66rame_id\x18\x02 \x01(\t\x12\t\n\x01x\x18\x03 \x01(\x01\x12\t\n\x01y\x18\x04 \x01(\x01\x12\r\n\x05width\x18\x05 \x01(\x01\x12\x0e\n\x06height\x18\x06 \x01(\x01\x12\r\n\x05min_z\x18\x07 \x01(\x01\x12\r\n\x05max_z\x18\x08 \x01(\x01\x62\x06proto3')

_globals = globals()
_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, _globals)
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'make87_messages_ros2.humble.map_msgs.msg.projected_map_info_pb2', _globals)
if _descriptor._USE_C_DESCRIPTORS == False:

  DESCRIPTOR._options = None
  _globals['_PROJECTEDMAPINFO']._serialized_start=147
  _globals['_PROJECTEDMAPINFO']._serialized_end=312
# @@protoc_insertion_point(module_scope)



from make87_messages_ros2.jazzy.std_msgs.msg import color_rgba_pb2 as _color_rgba_pb2
from google.protobuf import descriptor as _descriptor
from google.protobuf import message as _message
from typing import ClassVar as _ClassVar, Mapping as _Mapping, Optional as _Optional, Union as _Union

DESCRIPTOR: _descriptor.FileDescriptor

class SetLightPropertiesRequest(_message.Message):
    __slots__ = ["light_name", "diffuse", "attenuation_constant", "attenuation_linear", "attenuation_quadratic"]
    LIGHT_NAME_FIELD_NUMBER: _ClassVar[int]
    DIFFUSE_FIELD_NUMBER: _ClassVar[int]
    ATTENUATION_CONSTANT_FIELD_NUMBER: _ClassVar[int]
    ATTENUATION_LINEAR_FIELD_NUMBER: _ClassVar[int]
    ATTENUATION_QUADRATIC_FIELD_NUMBER: _ClassVar[int]
    light_name: str
    diffuse: _color_rgba_pb2.ColorRGBA
    attenuation_constant: float
    attenuation_linear: float
    attenuation_quadratic: float
    def __init__(self, light_name: _Optional[str] = ..., diffuse: _Optional[_Union[_color_rgba_pb2.ColorRGBA, _Mapping]] = ..., attenuation_constant: _Optional[float] = ..., attenuation_linear: _Optional[float] = ..., attenuation_quadratic: _Optional[float] = ...) -> None: ...

class SetLightPropertiesResponse(_message.Message):
    __slots__ = ["success", "status_message"]
    SUCCESS_FIELD_NUMBER: _ClassVar[int]
    STATUS_MESSAGE_FIELD_NUMBER: _ClassVar[int]
    success: bool
    status_message: str
    def __init__(self, success: bool = ..., status_message: _Optional[str] = ...) -> None: ...



from make87_messages_ros2.jazzy.std_msgs.msg import header_pb2 as _header_pb2
from google.protobuf import descriptor as _descriptor
from google.protobuf import message as _message
from typing import ClassVar as _ClassVar, Mapping as _Mapping, Optional as _Optional, Union as _Union

DESCRIPTOR: _descriptor.FileDescriptor

class AdaptiveCruiseControlCommand(_message.Message):
    __slots__ = ["header", "msg_counter", "set_speed", "set", "resume", "cancel", "speed_up", "slow_down", "further", "closer"]
    HEADER_FIELD_NUMBER: _ClassVar[int]
    MSG_COUNTER_FIELD_NUMBER: _ClassVar[int]
    SET_SPEED_FIELD_NUMBER: _ClassVar[int]
    SET_FIELD_NUMBER: _ClassVar[int]
    RESUME_FIELD_NUMBER: _ClassVar[int]
    CANCEL_FIELD_NUMBER: _ClassVar[int]
    SPEED_UP_FIELD_NUMBER: _ClassVar[int]
    SLOW_DOWN_FIELD_NUMBER: _ClassVar[int]
    FURTHER_FIELD_NUMBER: _ClassVar[int]
    CLOSER_FIELD_NUMBER: _ClassVar[int]
    header: _header_pb2.Header
    msg_counter: int
    set_speed: float
    set: int
    resume: int
    cancel: int
    speed_up: int
    slow_down: int
    further: int
    closer: int
    def __init__(self, header: _Optional[_Union[_header_pb2.Header, _Mapping]] = ..., msg_counter: _Optional[int] = ..., set_speed: _Optional[float] = ..., set: _Optional[int] = ..., resume: _Optional[int] = ..., cancel: _Optional[int] = ..., speed_up: _Optional[int] = ..., slow_down: _Optional[int] = ..., further: _Optional[int] = ..., closer: _Optional[int] = ...) -> None: ...



# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: make87_messages_ros2/jazzy/moveit_msgs/msg/robot_trajectory.proto
"""Generated protocol buffer code."""
from google.protobuf.internal import builder as _builder
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import symbol_database as _symbol_database
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from make87_messages_ros2.jazzy.trajectory_msgs.msg import joint_trajectory_pb2 as make87__messages__ros2_dot_jazzy_dot_trajectory__msgs_dot_msg_dot_joint__trajectory__pb2
from make87_messages_ros2.jazzy.trajectory_msgs.msg import multi_dof_joint_trajectory_pb2 as make87__messages__ros2_dot_jazzy_dot_trajectory__msgs_dot_msg_dot_multi__dof__joint__trajectory__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\nAmake87_messages_ros2/jazzy/moveit_msgs/msg/robot_trajectory.proto\x12*make87_messages_ros2.jazzy.moveit_msgs.msg\x1a\x45make87_messages_ros2/jazzy/trajectory_msgs/msg/joint_trajectory.proto\x1aOmake87_messages_ros2/jazzy/trajectory_msgs/msg/multi_dof_joint_trajectory.proto\"\xd9\x01\n\x0fRobotTrajectory\x12Y\n\x10joint_trajectory\x18\x01 \x01(\x0b\x32?.make87_messages_ros2.jazzy.trajectory_msgs.msg.JointTrajectory\x12k\n\x1amulti_dof_joint_trajectory\x18\x02 \x01(\x0b\x32G.make87_messages_ros2.jazzy.trajectory_msgs.msg.MultiDOFJointTrajectoryb\x06proto3')

_globals = globals()
_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, _globals)
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'make87_messages_ros2.jazzy.moveit_msgs.msg.robot_trajectory_pb2', _globals)
if _descriptor._USE_C_DESCRIPTORS == False:

  DESCRIPTOR._options = None
  _globals['_ROBOTTRAJECTORY']._serialized_start=266
  _globals['_ROBOTTRAJECTORY']._serialized_end=483
# @@protoc_insertion_point(module_scope)



from make87_messages_ros2.rolling.moveit_msgs.msg import motion_plan_request_pb2 as _motion_plan_request_pb2
from google.protobuf import descriptor as _descriptor
from google.protobuf import message as _message
from typing import ClassVar as _ClassVar, Mapping as _Mapping, Optional as _Optional, Union as _Union

DESCRIPTOR: _descriptor.FileDescriptor

class MotionSequenceItem(_message.Message):
    __slots__ = ["req", "blend_radius"]
    REQ_FIELD_NUMBER: _ClassVar[int]
    BLEND_RADIUS_FIELD_NUMBER: _ClassVar[int]
    req: _motion_plan_request_pb2.MotionPlanRequest
    blend_radius: float
    def __init__(self, req: _Optional[_Union[_motion_plan_request_pb2.MotionPlanRequest, _Mapping]] = ..., blend_radius: _Optional[float] = ...) -> None: ...



# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: make87_messages_ros2/humble/marti_introspection_msgs/msg/node_info.proto
"""Generated protocol buffer code."""
from google.protobuf.internal import builder as _builder
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import symbol_database as _symbol_database
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from make87_messages.core import header_pb2 as make87__messages_dot_core_dot_header__pb2
from make87_messages_ros2.humble.marti_introspection_msgs.msg import param_info_pb2 as make87__messages__ros2_dot_humble_dot_marti__introspection__msgs_dot_msg_dot_param__info__pb2
from make87_messages_ros2.humble.marti_introspection_msgs.msg import service_info_pb2 as make87__messages__ros2_dot_humble_dot_marti__introspection__msgs_dot_msg_dot_service__info__pb2
from make87_messages_ros2.humble.marti_introspection_msgs.msg import topic_info_pb2 as make87__messages__ros2_dot_humble_dot_marti__introspection__msgs_dot_msg_dot_topic__info__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\nHmake87_messages_ros2/humble/marti_introspection_msgs/msg/node_info.proto\x12\x38make87_messages_ros2.humble.marti_introspection_msgs.msg\x1a!make87_messages/core/header.proto\x1aImake87_messages_ros2/humble/marti_introspection_msgs/msg/param_info.proto\x1aKmake87_messages_ros2/humble/marti_introspection_msgs/msg/service_info.proto\x1aImake87_messages_ros2/humble/marti_introspection_msgs/msg/topic_info.proto\"\x8d\x03\n\x08NodeInfo\x12,\n\x06header\x18\x01 \x01(\x0b\x32\x1c.make87_messages.core.Header\x12\x0c\n\x04name\x18\x02 \x01(\t\x12\x10\n\x08location\x18\x03 \x01(\t\x12\x17\n\x0fnodelet_manager\x18\x04 \x01(\t\x12\x13\n\x0b\x64\x65scription\x18\x05 \x01(\t\x12S\n\x06topics\x18\x06 \x03(\x0b\x32\x43.make87_messages_ros2.humble.marti_introspection_msgs.msg.TopicInfo\x12W\n\nparameters\x18\x07 \x03(\x0b\x32\x43.make87_messages_ros2.humble.marti_introspection_msgs.msg.ParamInfo\x12W\n\x08services\x18\x08 \x03(\x0b\x32\x45.make87_messages_ros2.humble.marti_introspection_msgs.msg.ServiceInfob\x06proto3')

_globals = globals()
_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, _globals)
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'make87_messages_ros2.humble.marti_introspection_msgs.msg.node_info_pb2', _globals)
if _descriptor._USE_C_DESCRIPTORS == False:

  DESCRIPTOR._options = None
  _globals['_NODEINFO']._serialized_start=397
  _globals['_NODEINFO']._serialized_end=794
# @@protoc_insertion_point(module_scope)



from make87_messages.core import header_pb2 as _header_pb2
from make87_messages_ros2.humble.geometry_msgs.msg import pose2_d_pb2 as _pose2_d_pb2
from google.protobuf import descriptor as _descriptor
from google.protobuf import message as _message
from typing import ClassVar as _ClassVar, Mapping as _Mapping, Optional as _Optional, Union as _Union

DESCRIPTOR: _descriptor.FileDescriptor

class NormalizedImageCropRequest(_message.Message):
    __slots__ = ["header", "top_left", "bottom_right"]
    HEADER_FIELD_NUMBER: _ClassVar[int]
    TOP_LEFT_FIELD_NUMBER: _ClassVar[int]
    BOTTOM_RIGHT_FIELD_NUMBER: _ClassVar[int]
    header: _header_pb2.Header
    top_left: _pose2_d_pb2.Pose2D
    bottom_right: _pose2_d_pb2.Pose2D
    def __init__(self, header: _Optional[_Union[_header_pb2.Header, _Mapping]] = ..., top_left: _Optional[_Union[_pose2_d_pb2.Pose2D, _Mapping]] = ..., bottom_right: _Optional[_Union[_pose2_d_pb2.Pose2D, _Mapping]] = ...) -> None: ...

class NormalizedImageCropResponse(_message.Message):
    __slots__ = ["header", "status"]
    HEADER_FIELD_NUMBER: _ClassVar[int]
    STATUS_FIELD_NUMBER: _ClassVar[int]
    header: _header_pb2.Header
    status: int
    def __init__(self, header: _Optional[_Union[_header_pb2.Header, _Mapping]] = ..., status: _Optional[int] = ...) -> None: ...



from make87_messages_ros2.jazzy.std_msgs.msg import header_pb2 as _header_pb2
from google.protobuf import descriptor as _descriptor
from google.protobuf import message as _message
from typing import ClassVar as _ClassVar, Mapping as _Mapping, Optional as _Optional, Union as _Union

DESCRIPTOR: _descriptor.FileDescriptor

class MrrControlMsgNR(_message.Message):
    __slots__ = ["header", "can_stop_frequency_nrml", "can_prp_factor_nrml", "can_desired_sweep_bw_nrml", "can_radiation_ctrl", "can_stop_frequency_nrll", "can_prp_factor_nrll", "can_desired_sweep_bw_nrll"]
    HEADER_FIELD_NUMBER: _ClassVar[int]
    CAN_STOP_FREQUENCY_NRML_FIELD_NUMBER: _ClassVar[int]
    CAN_PRP_FACTOR_NRML_FIELD_NUMBER: _ClassVar[int]
    CAN_DESIRED_SWEEP_BW_NRML_FIELD_NUMBER: _ClassVar[int]
    CAN_RADIATION_CTRL_FIELD_NUMBER: _ClassVar[int]
    CAN_STOP_FREQUENCY_NRLL_FIELD_NUMBER: _ClassVar[int]
    CAN_PRP_FACTOR_NRLL_FIELD_NUMBER: _ClassVar[int]
    CAN_DESIRED_SWEEP_BW_NRLL_FIELD_NUMBER: _ClassVar[int]
    header: _header_pb2.Header
    can_stop_frequency_nrml: int
    can_prp_factor_nrml: int
    can_desired_sweep_bw_nrml: int
    can_radiation_ctrl: bool
    can_stop_frequency_nrll: int
    can_prp_factor_nrll: int
    can_desired_sweep_bw_nrll: int
    def __init__(self, header: _Optional[_Union[_header_pb2.Header, _Mapping]] = ..., can_stop_frequency_nrml: _Optional[int] = ..., can_prp_factor_nrml: _Optional[int] = ..., can_desired_sweep_bw_nrml: _Optional[int] = ..., can_radiation_ctrl: bool = ..., can_stop_frequency_nrll: _Optional[int] = ..., can_prp_factor_nrll: _Optional[int] = ..., can_desired_sweep_bw_nrll: _Optional[int] = ...) -> None: ...



from make87_messages_ros2.jazzy.geometry_msgs.msg import pose_pb2 as _pose_pb2
from make87_messages_ros2.jazzy.rc_common_msgs.msg import return_code_pb2 as _return_code_pb2
from make87_messages_ros2.jazzy.shape_msgs.msg import plane_pb2 as _plane_pb2
from google.protobuf import descriptor as _descriptor
from google.protobuf import message as _message
from typing import ClassVar as _ClassVar, Mapping as _Mapping, Optional as _Optional, Union as _Union

DESCRIPTOR: _descriptor.FileDescriptor

class GetBasePlaneCalibrationRequest(_message.Message):
    __slots__ = ["pose_frame", "robot_pose"]
    POSE_FRAME_FIELD_NUMBER: _ClassVar[int]
    ROBOT_POSE_FIELD_NUMBER: _ClassVar[int]
    pose_frame: str
    robot_pose: _pose_pb2.Pose
    def __init__(self, pose_frame: _Optional[str] = ..., robot_pose: _Optional[_Union[_pose_pb2.Pose, _Mapping]] = ...) -> None: ...

class GetBasePlaneCalibrationResponse(_message.Message):
    __slots__ = ["pose_frame", "plane", "return_code"]
    POSE_FRAME_FIELD_NUMBER: _ClassVar[int]
    PLANE_FIELD_NUMBER: _ClassVar[int]
    RETURN_CODE_FIELD_NUMBER: _ClassVar[int]
    pose_frame: str
    plane: _plane_pb2.Plane
    return_code: _return_code_pb2.ReturnCode
    def __init__(self, pose_frame: _Optional[str] = ..., plane: _Optional[_Union[_plane_pb2.Plane, _Mapping]] = ..., return_code: _Optional[_Union[_return_code_pb2.ReturnCode, _Mapping]] = ...) -> None: ...



from make87_messages_ros2.jazzy.std_msgs.msg import header_pb2 as _header_pb2
from google.protobuf import descriptor as _descriptor
from google.protobuf import message as _message
from typing import ClassVar as _ClassVar, Mapping as _Mapping, Optional as _Optional, Union as _Union

DESCRIPTOR: _descriptor.FileDescriptor

class EnhancedPositionRpt(_message.Message):
    __slots__ = ["header", "shaft_extension", "motor_overload_error", "clutch_overload_error", "motor_open_load_error", "clutch_open_load_error", "position_reach_error", "hardware_warning_1_error", "hardware_warning_2_error", "motor_current"]
    HEADER_FIELD_NUMBER: _ClassVar[int]
    SHAFT_EXTENSION_FIELD_NUMBER: _ClassVar[int]
    MOTOR_OVERLOAD_ERROR_FIELD_NUMBER: _ClassVar[int]
    CLUTCH_OVERLOAD_ERROR_FIELD_NUMBER: _ClassVar[int]
    MOTOR_OPEN_LOAD_ERROR_FIELD_NUMBER: _ClassVar[int]
    CLUTCH_OPEN_LOAD_ERROR_FIELD_NUMBER: _ClassVar[int]
    POSITION_REACH_ERROR_FIELD_NUMBER: _ClassVar[int]
    HARDWARE_WARNING_1_ERROR_FIELD_NUMBER: _ClassVar[int]
    HARDWARE_WARNING_2_ERROR_FIELD_NUMBER: _ClassVar[int]
    MOTOR_CURRENT_FIELD_NUMBER: _ClassVar[int]
    header: _header_pb2.Header
    shaft_extension: float
    motor_overload_error: bool
    clutch_overload_error: bool
    motor_open_load_error: bool
    clutch_open_load_error: bool
    position_reach_error: bool
    hardware_warning_1_error: bool
    hardware_warning_2_error: bool
    motor_current: int
    def __init__(self, header: _Optional[_Union[_header_pb2.Header, _Mapping]] = ..., shaft_extension: _Optional[float] = ..., motor_overload_error: bool = ..., clutch_overload_error: bool = ..., motor_open_load_error: bool = ..., clutch_open_load_error: bool = ..., position_reach_error: bool = ..., hardware_warning_1_error: bool = ..., hardware_warning_2_error: bool = ..., motor_current: _Optional[int] = ...) -> None: ...



# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: make87_messages_ros2/jazzy/ur_msgs/srv/get_robot_software_version.proto
"""Generated protocol buffer code."""
from google.protobuf.internal import builder as _builder
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import symbol_database as _symbol_database
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()




DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\nGmake87_messages_ros2/jazzy/ur_msgs/srv/get_robot_software_version.proto\x12&make87_messages_ros2.jazzy.ur_msgs.srv\" \n\x1eGetRobotSoftwareVersionRequest\"^\n\x1fGetRobotSoftwareVersionResponse\x12\r\n\x05major\x18\x01 \x01(\r\x12\r\n\x05minor\x18\x02 \x01(\r\x12\x0e\n\x06\x62ugfix\x18\x03 \x01(\r\x12\r\n\x05\x62uild\x18\x04 \x01(\rb\x06proto3')

_globals = globals()
_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, _globals)
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'make87_messages_ros2.jazzy.ur_msgs.srv.get_robot_software_version_pb2', _globals)
if _descriptor._USE_C_DESCRIPTORS == False:

  DESCRIPTOR._options = None
  _globals['_GETROBOTSOFTWAREVERSIONREQUEST']._serialized_start=115
  _globals['_GETROBOTSOFTWAREVERSIONREQUEST']._serialized_end=147
  _globals['_GETROBOTSOFTWAREVERSIONRESPONSE']._serialized_start=149
  _globals['_GETROBOTSOFTWAREVERSIONRESPONSE']._serialized_end=243
# @@protoc_insertion_point(module_scope)



from make87_messages_ros2.jazzy.std_msgs.msg import header_pb2 as _header_pb2
from google.protobuf.internal import containers as _containers
from google.protobuf import descriptor as _descriptor
from google.protobuf import message as _message
from typing import ClassVar as _ClassVar, Iterable as _Iterable, Mapping as _Mapping, Optional as _Optional, Union as _Union

DESCRIPTOR: _descriptor.FileDescriptor

class Packet(_message.Message):
    __slots__ = ["header", "data", "b_o_s", "e_o_s", "granulepos", "packetno"]
    HEADER_FIELD_NUMBER: _ClassVar[int]
    DATA_FIELD_NUMBER: _ClassVar[int]
    B_O_S_FIELD_NUMBER: _ClassVar[int]
    E_O_S_FIELD_NUMBER: _ClassVar[int]
    GRANULEPOS_FIELD_NUMBER: _ClassVar[int]
    PACKETNO_FIELD_NUMBER: _ClassVar[int]
    header: _header_pb2.Header
    data: _containers.RepeatedScalarFieldContainer[int]
    b_o_s: int
    e_o_s: int
    granulepos: int
    packetno: int
    def __init__(self, header: _Optional[_Union[_header_pb2.Header, _Mapping]] = ..., data: _Optional[_Iterable[int]] = ..., b_o_s: _Optional[int] = ..., e_o_s: _Optional[int] = ..., granulepos: _Optional[int] = ..., packetno: _Optional[int] = ...) -> None: ...



from google.protobuf import descriptor as _descriptor
from google.protobuf import message as _message
from typing import ClassVar as _ClassVar, Optional as _Optional

DESCRIPTOR: _descriptor.FileDescriptor

class LedColor(_message.Message):
    __slots__ = ["red", "green", "blue"]
    RED_FIELD_NUMBER: _ClassVar[int]
    GREEN_FIELD_NUMBER: _ClassVar[int]
    BLUE_FIELD_NUMBER: _ClassVar[int]
    red: int
    green: int
    blue: int
    def __init__(self, red: _Optional[int] = ..., green: _Optional[int] = ..., blue: _Optional[int] = ...) -> None: ...



# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: make87_messages_ros2/jazzy/rcl_interfaces/srv/describe_parameters.proto
"""Generated protocol buffer code."""
from google.protobuf.internal import builder as _builder
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import symbol_database as _symbol_database
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from make87_messages_ros2.jazzy.rcl_interfaces.msg import parameter_descriptor_pb2 as make87__messages__ros2_dot_jazzy_dot_rcl__interfaces_dot_msg_dot_parameter__descriptor__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\nGmake87_messages_ros2/jazzy/rcl_interfaces/srv/describe_parameters.proto\x12-make87_messages_ros2.jazzy.rcl_interfaces.srv\x1aHmake87_messages_ros2/jazzy/rcl_interfaces/msg/parameter_descriptor.proto\"*\n\x19\x44\x65scribeParametersRequest\x12\r\n\x05names\x18\x01 \x03(\t\"u\n\x1a\x44\x65scribeParametersResponse\x12W\n\x0b\x64\x65scriptors\x18\x01 \x03(\x0b\x32\x42.make87_messages_ros2.jazzy.rcl_interfaces.msg.ParameterDescriptorb\x06proto3')

_globals = globals()
_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, _globals)
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'make87_messages_ros2.jazzy.rcl_interfaces.srv.describe_parameters_pb2', _globals)
if _descriptor._USE_C_DESCRIPTORS == False:

  DESCRIPTOR._options = None
  _globals['_DESCRIBEPARAMETERSREQUEST']._serialized_start=196
  _globals['_DESCRIBEPARAMETERSREQUEST']._serialized_end=238
  _globals['_DESCRIBEPARAMETERSRESPONSE']._serialized_start=240
  _globals['_DESCRIBEPARAMETERSRESPONSE']._serialized_end=357
# @@protoc_insertion_point(module_scope)



# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: make87_messages_ros2/humble/sick_safetyscanners2_interfaces/msg/application_inputs.proto
"""Generated protocol buffer code."""
from google.protobuf.internal import builder as _builder
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import symbol_database as _symbol_database
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from make87_messages.core import header_pb2 as make87__messages_dot_core_dot_header__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\nXmake87_messages_ros2/humble/sick_safetyscanners2_interfaces/msg/application_inputs.proto\x12?make87_messages_ros2.humble.sick_safetyscanners2_interfaces.msg\x1a!make87_messages/core/header.proto\"\xa5\x04\n\x11\x41pplicationInputs\x12,\n\x06header\x18\x01 \x01(\x0b\x32\x1c.make87_messages.core.Header\x12#\n\x1bunsafe_inputs_input_sources\x18\x02 \x03(\x08\x12\x1b\n\x13unsafe_inputs_flags\x18\x03 \x03(\x08\x12%\n\x1dmonitoring_case_number_inputs\x18\x04 \x03(\r\x12+\n#monitoring_case_number_inputs_flags\x18\x05 \x03(\x08\x12)\n!linear_velocity_inputs_velocity_0\x18\x06 \x01(\x05\x12/\n\'linear_velocity_inputs_velocity_0_valid\x18\x07 \x01(\x08\x12<\n4linear_velocity_inputs_velocity_0_transmitted_safely\x18\x08 \x01(\x08\x12)\n!linear_velocity_inputs_velocity_1\x18\t \x01(\x05\x12/\n\'linear_velocity_inputs_velocity_1_valid\x18\n \x01(\x08\x12<\n4linear_velocity_inputs_velocity_1_transmitted_safely\x18\x0b \x01(\x08\x12\x18\n\x10sleep_mode_input\x18\x0c \x01(\rb\x06proto3')

_globals = globals()
_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, _globals)
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'make87_messages_ros2.humble.sick_safetyscanners2_interfaces.msg.application_inputs_pb2', _globals)
if _descriptor._USE_C_DESCRIPTORS == False:

  DESCRIPTOR._options = None
  _globals['_APPLICATIONINPUTS']._serialized_start=193
  _globals['_APPLICATIONINPUTS']._serialized_end=742
# @@protoc_insertion_point(module_scope)



from google.protobuf import descriptor as _descriptor
from google.protobuf import message as _message
from typing import ClassVar as _ClassVar, Optional as _Optional

DESCRIPTOR: _descriptor.FileDescriptor

class GetROSVersionRequest(_message.Message):
    __slots__ = []
    def __init__(self) -> None: ...

class GetROSVersionResponse(_message.Message):
    __slots__ = ["version", "distro"]
    VERSION_FIELD_NUMBER: _ClassVar[int]
    DISTRO_FIELD_NUMBER: _ClassVar[int]
    version: int
    distro: str
    def __init__(self, version: _Optional[int] = ..., distro: _Optional[str] = ...) -> None: ...



from make87_messages_ros2.jazzy.std_msgs.msg import header_pb2 as _header_pb2
from google.protobuf import descriptor as _descriptor
from google.protobuf import message as _message
from typing import ClassVar as _ClassVar, Mapping as _Mapping, Optional as _Optional, Union as _Union

DESCRIPTOR: _descriptor.FileDescriptor

class BatteryTraction(_message.Message):
    __slots__ = ["header", "state_of_charge", "voltage", "current", "temperature", "status"]
    HEADER_FIELD_NUMBER: _ClassVar[int]
    STATE_OF_CHARGE_FIELD_NUMBER: _ClassVar[int]
    VOLTAGE_FIELD_NUMBER: _ClassVar[int]
    CURRENT_FIELD_NUMBER: _ClassVar[int]
    TEMPERATURE_FIELD_NUMBER: _ClassVar[int]
    STATUS_FIELD_NUMBER: _ClassVar[int]
    header: _header_pb2.Header
    state_of_charge: float
    voltage: float
    current: float
    temperature: float
    status: int
    def __init__(self, header: _Optional[_Union[_header_pb2.Header, _Mapping]] = ..., state_of_charge: _Optional[float] = ..., voltage: _Optional[float] = ..., current: _Optional[float] = ..., temperature: _Optional[float] = ..., status: _Optional[int] = ...) -> None: ...



from make87_messages_ros2.rolling.autoware_map_msgs.msg import lanelet_map_cell_meta_data_pb2 as _lanelet_map_cell_meta_data_pb2
from make87_messages_ros2.rolling.std_msgs.msg import header_pb2 as _header_pb2
from google.protobuf.internal import containers as _containers
from google.protobuf import descriptor as _descriptor
from google.protobuf import message as _message
from typing import ClassVar as _ClassVar, Iterable as _Iterable, Mapping as _Mapping, Optional as _Optional, Union as _Union

DESCRIPTOR: _descriptor.FileDescriptor

class LaneletMapMetaData(_message.Message):
    __slots__ = ["header", "metadata_list"]
    HEADER_FIELD_NUMBER: _ClassVar[int]
    METADATA_LIST_FIELD_NUMBER: _ClassVar[int]
    header: _header_pb2.Header
    metadata_list: _containers.RepeatedCompositeFieldContainer[_lanelet_map_cell_meta_data_pb2.LaneletMapCellMetaData]
    def __init__(self, header: _Optional[_Union[_header_pb2.Header, _Mapping]] = ..., metadata_list: _Optional[_Iterable[_Union[_lanelet_map_cell_meta_data_pb2.LaneletMapCellMetaData, _Mapping]]] = ...) -> None: ...



from make87_messages.core import header_pb2 as _header_pb2
from google.protobuf import descriptor as _descriptor
from google.protobuf import message as _message
from typing import ClassVar as _ClassVar, Mapping as _Mapping, Optional as _Optional, Union as _Union

DESCRIPTOR: _descriptor.FileDescriptor

class ReloadControllerLibrariesRequest(_message.Message):
    __slots__ = ["header", "force_kill"]
    HEADER_FIELD_NUMBER: _ClassVar[int]
    FORCE_KILL_FIELD_NUMBER: _ClassVar[int]
    header: _header_pb2.Header
    force_kill: bool
    def __init__(self, header: _Optional[_Union[_header_pb2.Header, _Mapping]] = ..., force_kill: bool = ...) -> None: ...

class ReloadControllerLibrariesResponse(_message.Message):
    __slots__ = ["header", "ok"]
    HEADER_FIELD_NUMBER: _ClassVar[int]
    OK_FIELD_NUMBER: _ClassVar[int]
    header: _header_pb2.Header
    ok: bool
    def __init__(self, header: _Optional[_Union[_header_pb2.Header, _Mapping]] = ..., ok: bool = ...) -> None: ...



# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: make87_messages_ros2/rolling/tuw_multi_robot_msgs/msg/robot_info.proto
"""Generated protocol buffer code."""
from google.protobuf.internal import builder as _builder
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import symbol_database as _symbol_database
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from make87_messages_ros2.rolling.geometry_msgs.msg import pose_with_covariance_pb2 as make87__messages__ros2_dot_rolling_dot_geometry__msgs_dot_msg_dot_pose__with__covariance__pb2
from make87_messages_ros2.rolling.std_msgs.msg import header_pb2 as make87__messages__ros2_dot_rolling_dot_std__msgs_dot_msg_dot_header__pb2
from make87_messages_ros2.rolling.tuw_multi_robot_msgs.msg import route_precondition_pb2 as make87__messages__ros2_dot_rolling_dot_tuw__multi__robot__msgs_dot_msg_dot_route__precondition__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\nFmake87_messages_ros2/rolling/tuw_multi_robot_msgs/msg/robot_info.proto\x12\x35make87_messages_ros2.rolling.tuw_multi_robot_msgs.msg\x1aImake87_messages_ros2/rolling/geometry_msgs/msg/pose_with_covariance.proto\x1a\x36make87_messages_ros2/rolling/std_msgs/msg/header.proto\x1aNmake87_messages_ros2/rolling/tuw_multi_robot_msgs/msg/route_precondition.proto\"\x8b\x03\n\tRobotInfo\x12\x41\n\x06header\x18\x01 \x01(\x0b\x32\x31.make87_messages_ros2.rolling.std_msgs.msg.Header\x12\x12\n\nrobot_name\x18\x02 \x01(\t\x12P\n\x04pose\x18\x03 \x01(\x0b\x32\x42.make87_messages_ros2.rolling.geometry_msgs.msg.PoseWithCovariance\x12\r\n\x05shape\x18\x04 \x01(\x05\x12\x17\n\x0fshape_variables\x18\x05 \x03(\x02\x12V\n\x04sync\x18\x06 \x01(\x0b\x32H.make87_messages_ros2.rolling.tuw_multi_robot_msgs.msg.RoutePrecondition\x12\x0c\n\x04mode\x18\x07 \x01(\x05\x12\x0e\n\x06status\x18\x08 \x01(\x05\x12\x0f\n\x07good_id\x18\t \x01(\x05\x12\x10\n\x08order_id\x18\n \x01(\x05\x12\x14\n\x0corder_status\x18\x0b \x01(\x05\x62\x06proto3')

_globals = globals()
_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, _globals)
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'make87_messages_ros2.rolling.tuw_multi_robot_msgs.msg.robot_info_pb2', _globals)
if _descriptor._USE_C_DESCRIPTORS == False:

  DESCRIPTOR._options = None
  _globals['_ROBOTINFO']._serialized_start=341
  _globals['_ROBOTINFO']._serialized_end=736
# @@protoc_insertion_point(module_scope)



# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: make87_messages_ros2/humble/ublox_msgs/msg/cfg_nmea.proto
"""Generated protocol buffer code."""
from google.protobuf.internal import builder as _builder
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import symbol_database as _symbol_database
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from make87_messages.core import header_pb2 as make87__messages_dot_core_dot_header__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n9make87_messages_ros2/humble/ublox_msgs/msg/cfg_nmea.proto\x12*make87_messages_ros2.humble.ublox_msgs.msg\x1a!make87_messages/core/header.proto\"\x94\x02\n\x07\x43\x66gNMEA\x12,\n\x06header\x18\x01 \x01(\x0b\x32\x1c.make87_messages.core.Header\x12\x0e\n\x06\x66ilter\x18\x02 \x01(\r\x12\x14\n\x0cnmea_version\x18\x03 \x01(\r\x12\x0e\n\x06num_sv\x18\x04 \x01(\r\x12\r\n\x05\x66lags\x18\x05 \x01(\r\x12\x16\n\x0egnss_to_filter\x18\x06 \x01(\r\x12\x14\n\x0csv_numbering\x18\x07 \x01(\r\x12\x16\n\x0emain_talker_id\x18\x08 \x01(\r\x12\x15\n\rgsv_talker_id\x18\t \x01(\r\x12\x0f\n\x07version\x18\n \x01(\r\x12\x15\n\rbds_talker_id\x18\x0b \x03(\r\x12\x11\n\treserved1\x18\x0c \x03(\rb\x06proto3')

_globals = globals()
_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, _globals)
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'make87_messages_ros2.humble.ublox_msgs.msg.cfg_nmea_pb2', _globals)
if _descriptor._USE_C_DESCRIPTORS == False:

  DESCRIPTOR._options = None
  _globals['_CFGNMEA']._serialized_start=141
  _globals['_CFGNMEA']._serialized_end=417
# @@protoc_insertion_point(module_scope)



# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: make87_messages_ros2/jazzy/gazebo_msgs/srv/apply_body_wrench.proto
"""Generated protocol buffer code."""
from google.protobuf.internal import builder as _builder
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import symbol_database as _symbol_database
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from make87_messages_ros2.jazzy.builtin_interfaces.msg import duration_pb2 as make87__messages__ros2_dot_jazzy_dot_builtin__interfaces_dot_msg_dot_duration__pb2
from make87_messages_ros2.jazzy.builtin_interfaces.msg import time_pb2 as make87__messages__ros2_dot_jazzy_dot_builtin__interfaces_dot_msg_dot_time__pb2
from make87_messages_ros2.jazzy.geometry_msgs.msg import point_pb2 as make87__messages__ros2_dot_jazzy_dot_geometry__msgs_dot_msg_dot_point__pb2
from make87_messages_ros2.jazzy.geometry_msgs.msg import wrench_pb2 as make87__messages__ros2_dot_jazzy_dot_geometry__msgs_dot_msg_dot_wrench__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\nBmake87_messages_ros2/jazzy/gazebo_msgs/srv/apply_body_wrench.proto\x12*make87_messages_ros2.jazzy.gazebo_msgs.srv\x1a@make87_messages_ros2/jazzy/builtin_interfaces/msg/duration.proto\x1a<make87_messages_ros2/jazzy/builtin_interfaces/msg/time.proto\x1a\x38make87_messages_ros2/jazzy/geometry_msgs/msg/point.proto\x1a\x39make87_messages_ros2/jazzy/geometry_msgs/msg/wrench.proto\"\xf4\x02\n\x16\x41pplyBodyWrenchRequest\x12\x11\n\tbody_name\x18\x01 \x01(\t\x12\x17\n\x0freference_frame\x18\x02 \x01(\t\x12L\n\x0freference_point\x18\x03 \x01(\x0b\x32\x33.make87_messages_ros2.jazzy.geometry_msgs.msg.Point\x12\x44\n\x06wrench\x18\x04 \x01(\x0b\x32\x34.make87_messages_ros2.jazzy.geometry_msgs.msg.Wrench\x12K\n\nstart_time\x18\x05 \x01(\x0b\x32\x37.make87_messages_ros2.jazzy.builtin_interfaces.msg.Time\x12M\n\x08\x64uration\x18\x06 \x01(\x0b\x32;.make87_messages_ros2.jazzy.builtin_interfaces.msg.Duration\"B\n\x17\x41pplyBodyWrenchResponse\x12\x0f\n\x07success\x18\x01 \x01(\x08\x12\x16\n\x0estatus_message\x18\x02 \x01(\tb\x06proto3')

_globals = globals()
_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, _globals)
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'make87_messages_ros2.jazzy.gazebo_msgs.srv.apply_body_wrench_pb2', _globals)
if _descriptor._USE_C_DESCRIPTORS == False:

  DESCRIPTOR._options = None
  _globals['_APPLYBODYWRENCHREQUEST']._serialized_start=360
  _globals['_APPLYBODYWRENCHREQUEST']._serialized_end=732
  _globals['_APPLYBODYWRENCHRESPONSE']._serialized_start=734
  _globals['_APPLYBODYWRENCHRESPONSE']._serialized_end=800
# @@protoc_insertion_point(module_scope)



from make87_messages_ros2.rolling.std_msgs.msg import header_pb2 as _header_pb2
from google.protobuf import descriptor as _descriptor
from google.protobuf import message as _message
from typing import ClassVar as _ClassVar, Mapping as _Mapping, Optional as _Optional, Union as _Union

DESCRIPTOR: _descriptor.FileDescriptor

class EsrStatus6(_message.Message):
    __slots__ = ["header", "canmsg", "supply_1p8v_a2d", "supply_n5v_a2d", "wave_diff_a2d", "sw_version_dsp_3rd_byte", "vertical_align_updated", "system_power_mode", "found_target", "recommend_unconverge", "factory_align_status_1", "factory_align_status_2", "factory_misalignment", "serv_align_updates_done", "vertical_misalignment"]
    HEADER_FIELD_NUMBER: _ClassVar[int]
    CANMSG_FIELD_NUMBER: _ClassVar[int]
    SUPPLY_1P8V_A2D_FIELD_NUMBER: _ClassVar[int]
    SUPPLY_N5V_A2D_FIELD_NUMBER: _ClassVar[int]
    WAVE_DIFF_A2D_FIELD_NUMBER: _ClassVar[int]
    SW_VERSION_DSP_3RD_BYTE_FIELD_NUMBER: _ClassVar[int]
    VERTICAL_ALIGN_UPDATED_FIELD_NUMBER: _ClassVar[int]
    SYSTEM_POWER_MODE_FIELD_NUMBER: _ClassVar[int]
    FOUND_TARGET_FIELD_NUMBER: _ClassVar[int]
    RECOMMEND_UNCONVERGE_FIELD_NUMBER: _ClassVar[int]
    FACTORY_ALIGN_STATUS_1_FIELD_NUMBER: _ClassVar[int]
    FACTORY_ALIGN_STATUS_2_FIELD_NUMBER: _ClassVar[int]
    FACTORY_MISALIGNMENT_FIELD_NUMBER: _ClassVar[int]
    SERV_ALIGN_UPDATES_DONE_FIELD_NUMBER: _ClassVar[int]
    VERTICAL_MISALIGNMENT_FIELD_NUMBER: _ClassVar[int]
    header: _header_pb2.Header
    canmsg: str
    supply_1p8v_a2d: int
    supply_n5v_a2d: int
    wave_diff_a2d: int
    sw_version_dsp_3rd_byte: int
    vertical_align_updated: bool
    system_power_mode: int
    found_target: bool
    recommend_unconverge: bool
    factory_align_status_1: int
    factory_align_status_2: int
    factory_misalignment: float
    serv_align_updates_done: int
    vertical_misalignment: float
    def __init__(self, header: _Optional[_Union[_header_pb2.Header, _Mapping]] = ..., canmsg: _Optional[str] = ..., supply_1p8v_a2d: _Optional[int] = ..., supply_n5v_a2d: _Optional[int] = ..., wave_diff_a2d: _Optional[int] = ..., sw_version_dsp_3rd_byte: _Optional[int] = ..., vertical_align_updated: bool = ..., system_power_mode: _Optional[int] = ..., found_target: bool = ..., recommend_unconverge: bool = ..., factory_align_status_1: _Optional[int] = ..., factory_align_status_2: _Optional[int] = ..., factory_misalignment: _Optional[float] = ..., serv_align_updates_done: _Optional[int] = ..., vertical_misalignment: _Optional[float] = ...) -> None: ...



from make87_messages_ros2.rolling.rmf_traffic_msgs.msg import schedule_inconsistency_range_pb2 as _schedule_inconsistency_range_pb2
from google.protobuf.internal import containers as _containers
from google.protobuf import descriptor as _descriptor
from google.protobuf import message as _message
from typing import ClassVar as _ClassVar, Iterable as _Iterable, Mapping as _Mapping, Optional as _Optional, Union as _Union

DESCRIPTOR: _descriptor.FileDescriptor

class ScheduleInconsistency(_message.Message):
    __slots__ = ["participant", "ranges", "last_known_itinerary", "last_known_progress"]
    PARTICIPANT_FIELD_NUMBER: _ClassVar[int]
    RANGES_FIELD_NUMBER: _ClassVar[int]
    LAST_KNOWN_ITINERARY_FIELD_NUMBER: _ClassVar[int]
    LAST_KNOWN_PROGRESS_FIELD_NUMBER: _ClassVar[int]
    participant: int
    ranges: _containers.RepeatedCompositeFieldContainer[_schedule_inconsistency_range_pb2.ScheduleInconsistencyRange]
    last_known_itinerary: int
    last_known_progress: int
    def __init__(self, participant: _Optional[int] = ..., ranges: _Optional[_Iterable[_Union[_schedule_inconsistency_range_pb2.ScheduleInconsistencyRange, _Mapping]]] = ..., last_known_itinerary: _Optional[int] = ..., last_known_progress: _Optional[int] = ...) -> None: ...
